@@ -49,7 +49,8 @@ enum
     PROP_TIP_COL,
 };
 
-#define GNC_COMBOTT_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GNC_TYPE_COMBOTT, GncCombottPrivate))
+#define GNC_COMBOTT_GET_PRIVATE(o) \
+    ((GncCombottPrivate*)g_type_instance_get_private((GTypeInstance*)o, GNC_TYPE_COMBOTT))
 
 static guint combott_signals[LAST_SIGNAL] = {0,};
 
@@ -76,34 +77,26 @@ typedef struct GncCombottPrivate
 } GncCombottPrivate;
 
 /** Declarations *********************************************************/
-static void gctt_init (GncCombott *combott);
+static void gnc_combott_init (GncCombott *combott);
 
-static void gctt_class_init (GncCombottClass *klass);
+static void gnc_combott_class_init (GncCombottClass *klass);
 
-static void gctt_set_property (GObject *object,
+static void gnc_combott_set_property (GObject *object,
                                guint param_id,
                                const GValue *value,
                                GParamSpec *pspec);
 
-static void gctt_get_property (GObject *object,
+static void gnc_combott_get_property (GObject *object,
                                guint param_id,
                                GValue *value,
                                GParamSpec *pspec);
 
-static void gctt_finalize (GObject *object);
+static void gnc_combott_finalize (GObject *object);
 
-#if !GTK_CHECK_VERSION(3,22,0)
-static void gctt_combott_menu_position (GtkMenu *menu,
-                                        gint *x,
-                                        gint *y,
-                                        gint *push_in,
-                                        gpointer user_data);
-#endif
-
-static void gctt_changed (GncCombott *combott);
-static void gctt_set_model (GncCombott *combott, GtkTreeModel *model);
-static void gctt_refresh_menu (GncCombott *combott, GtkTreeModel *model);
-static void gctt_rebuild_menu (GncCombott *combott, GtkTreeModel *model);
+static void gnc_combott_changed (GncCombott *combott);
+static void gnc_combott_set_model (GncCombott *combott, GtkTreeModel *model);
+static void gnc_combott_refresh_menu (GncCombott *combott, GtkTreeModel *model);
+static void gnc_combott_rebuild_menu (GncCombott *combott, GtkTreeModel *model);
 
 static gboolean which_tooltip_cb (GtkWidget  *widget, gint x, gint y,
                                   gboolean keyboard_mode, GtkTooltip *tooltip, gpointer user_data);
@@ -118,47 +111,21 @@ static void menuitem_response_cb (GtkMenuItem *item, gpointer *user_data);
 /************************************************************/
 static GObjectClass *parent_class = NULL;
 
-GType
-gnc_combott_get_type (void)
-{
-    static GType combott_type = 0;
-
-    if (!combott_type)
-    {
-        static const GTypeInfo combott_info =
-        {
-            sizeof (GncCombottClass),
-            NULL,		/* base_init */
-            NULL,		/* base_finalize */
-            (GClassInitFunc) gctt_class_init,
-            NULL,		/* class_finalize */
-            NULL,		/* class_data */
-            sizeof (GncCombott),
-            0,              /* n_preallocs */
-            (GInstanceInitFunc) gctt_init,
-        };
-
-        combott_type = g_type_register_static (GTK_TYPE_BOX,
-                                               "GncCombott",
-                                               &combott_info, 0);
-    }
-    return combott_type;
-}
-
+G_DEFINE_TYPE_WITH_PRIVATE(GncCombott, gnc_combott, GTK_TYPE_BOX)
 
 static void
-gctt_class_init (GncCombottClass *klass)
+gnc_combott_class_init (GncCombottClass *klass)
 {
     GObjectClass            *gobject_class;
 
     parent_class = g_type_class_peek_parent (klass);
     gobject_class = G_OBJECT_CLASS (klass);
 
-    gobject_class->set_property = gctt_set_property;
-    gobject_class->get_property = gctt_get_property;
-    gobject_class->finalize = gctt_finalize;
+    gobject_class->set_property = gnc_combott_set_property;
+    gobject_class->get_property = gnc_combott_get_property;
+    gobject_class->finalize = gnc_combott_finalize;
 
-    klass->changed = gctt_changed;
+    klass->changed = gnc_combott_changed;
 
     combott_signals[CHANGED] =
         g_signal_new ("changed",
@@ -199,13 +166,11 @@ gctt_class_init (GncCombottClass *klass)
                           G_MAXINT,
                           1,
                           G_PARAM_READWRITE));
-
-    g_type_class_add_private(klass, sizeof(GncCombottPrivate));
 }
 
 
 static void
-gctt_init (GncCombott *combott)
+gnc_combott_init (GncCombott *combott)
 {
     GtkWidget *hbox;
     GtkWidget *label;
@@ -217,8 +182,8 @@ gctt_init (GncCombott *combott)
 
     gtk_orientable_set_orientation (GTK_ORIENTABLE(combott), GTK_ORIENTATION_HORIZONTAL);
 
-    // Set the style context for this widget so it can be easily manipulated with css
-    gnc_widget_set_style_context (GTK_WIDGET(combott), "GncCombott");
+    // Set the name for this widget so it can be easily manipulated with css
+    gtk_widget_set_name (GTK_WIDGET(combott), "gnc-id-combo-tooltip");
 
     priv->active = 0;
     priv->text_col = 0;
@@ -232,11 +197,7 @@ gctt_init (GncCombott *combott)
     g_signal_connect (G_OBJECT (arrow), "draw",
                       G_CALLBACK (gnc_draw_arrow_cb), GINT_TO_POINTER(1));
 
-#if GTK_CHECK_VERSION(3,12,0)
     gtk_widget_set_margin_start (GTK_WIDGET(arrow), 5);
-#else
-    gtk_widget_set_margin_left (GTK_WIDGET(arrow), 5);
-#endif
     gtk_box_pack_end (GTK_BOX (hbox), arrow, FALSE, FALSE, 0);
 
     sep = gtk_separator_new (GTK_ORIENTATION_VERTICAL);
@@ -268,7 +229,7 @@ gctt_init (GncCombott *combott)
 
 
 static void
-gctt_set_property (GObject      *object,
+gnc_combott_set_property (GObject      *object,
                    guint         param_id,
                    const GValue *value,
                    GParamSpec   *pspec)
@@ -279,7 +240,7 @@ gctt_set_property (GObject      *object,
     switch (param_id)
     {
     case PROP_MODEL:
-        gctt_set_model (combott, g_value_get_object (value));
+        gnc_combott_set_model (combott, g_value_get_object (value));
         break;
 
     case PROP_ACTIVE:
@@ -292,7 +253,7 @@ gctt_set_property (GObject      *object,
 
     case PROP_TIP_COL:
         priv->tip_col = g_value_get_int (value);
-        gctt_refresh_menu(combott, priv->model);
+        gnc_combott_refresh_menu(combott, priv->model);
         break;
 
     default:
@@ -308,7 +269,7 @@ gctt_set_property (GObject      *object,
  * ref the object when used in get_property().
  */
 static void
-gctt_get_property (GObject    *object,
+gnc_combott_get_property (GObject    *object,
                    guint       param_id,
                    GValue     *value,
                    GParamSpec *pspec)
@@ -342,7 +303,7 @@ gctt_get_property (GObject    *object,
 
 
 static void
-gctt_finalize (GObject *object)
+gnc_combott_finalize (GObject *object)
 {
     GncCombott *combott;
     GncCombottPrivate *priv;
@@ -368,7 +329,7 @@ gctt_finalize (GObject *object)
 
 
 static void
-gctt_set_model (GncCombott *combott, GtkTreeModel *model)
+gnc_combott_set_model (GncCombott *combott, GtkTreeModel *model)
 {
     GncCombottPrivate *priv;
 
@@ -377,7 +338,7 @@ gctt_set_model (GncCombott *combott, GtkTreeModel *model)
 
     priv = GNC_COMBOTT_GET_PRIVATE (combott);
 
-    gctt_rebuild_menu(combott, model);
+    gnc_combott_rebuild_menu(combott, model);
 
     priv->model = model;
     g_object_ref (priv->model);
@@ -385,7 +346,7 @@ gctt_set_model (GncCombott *combott, GtkTreeModel *model)
 
 
 static void
-gctt_rebuild_menu (GncCombott *combott, GtkTreeModel *model)
+gnc_combott_rebuild_menu (GncCombott *combott, GtkTreeModel *model)
 {
     GncCombottPrivate *priv;
     GtkTreeIter iter;
@@ -454,17 +415,17 @@ gctt_rebuild_menu (GncCombott *combott, GtkTreeModel *model)
 
 
 static void
-gctt_refresh_menu (GncCombott *combott, GtkTreeModel *model)
+gnc_combott_refresh_menu (GncCombott *combott, GtkTreeModel *model)
 {
     g_return_if_fail (GNC_IS_COMBOTT (combott));
     g_return_if_fail (model == NULL || GTK_IS_TREE_MODEL (model));
 
-    gctt_rebuild_menu(combott, model);
+    gnc_combott_rebuild_menu(combott, model);
 }
 
 
 static void
-gctt_changed(GncCombott *combott)
+gnc_combott_changed(GncCombott *combott)
 {
     /*
     g_print("Changed Signal\n");
@@ -472,61 +433,6 @@ gctt_changed(GncCombott *combott)
 }
 
 
-#if !GTK_CHECK_VERSION(3,22,0)
-static void
-gctt_combott_menu_position (GtkMenu  *menu,
-                            gint     *x,
-                            gint     *y,
-                            gint     *push_in,
-                            gpointer  user_data)
-{
-    GncCombott *combott = GNC_COMBOTT (user_data);
-    GncCombottPrivate *priv = GNC_COMBOTT_GET_PRIVATE (combott);
-    gint sx, sy;
-    GtkWidget *child;
-    GtkRequisition req;
-    GtkAllocation alloc;
-    GtkBorder padding;
-    GtkStyleContext *sc = gtk_widget_get_style_context (GTK_WIDGET (priv->button));
-    GtkStateFlags state_flags = gtk_style_context_get_state (sc);
-
-    child = gtk_bin_get_child (GTK_BIN (priv->button));
-
-    sx = sy = 0;
-
-    if (!gtk_widget_get_has_window (child))
-    {
-        gtk_widget_get_allocation (child, &alloc);
-        sx += alloc.x;
-        sy += alloc.y;
-    }
-
-    gdk_window_get_root_coords (gtk_widget_get_window (child), sx, sy, &sx, &sy);
-
-    gtk_style_context_get_padding (sc, state_flags, &padding);
-
-    sx -= padding.left;
-
-    gtk_widget_get_preferred_size (GTK_WIDGET (menu), &req, NULL);
-
-    if (gtk_widget_get_direction (GTK_WIDGET (priv->button)) == GTK_TEXT_DIR_LTR)
-        *x = sx;
-    else
-    {
-        gtk_widget_get_allocation (child, &alloc);
-        *x = sx + alloc.width - req.width;
-    }
-
-    if(priv->active == -1 || priv->active == 0)
-        *y = sy;
-    else
-        *y = sy - ((req.height / priv->num_items) * (priv->active - 1));
-
-    *push_in = FALSE;
-}
-#endif
-
-
 static void
 button_getsize_cb (GtkWidget *widget, GtkAllocation *allocation, gpointer *user_data)
 {
@@ -588,20 +494,11 @@ button_press_cb (GtkWidget *widget, GdkEvent *event, gpointer *user_data )
     {
         if (event->type == GDK_BUTTON_PRESS)
         {
-            GdkEventButton *bevent = (GdkEventButton *) event;
-
-#if GTK_CHECK_VERSION(3,22,0)
             gtk_menu_popup_at_widget (GTK_MENU(priv->menu),
                                       widget,
                                       GDK_GRAVITY_SOUTH_WEST,
                                       GDK_GRAVITY_NORTH_WEST,
                                       event);
-#else
-            gtk_menu_popup (GTK_MENU (priv->menu),
-                            NULL, NULL,
-                            gctt_combott_menu_position, combott,
-                            bevent->button, bevent->time);
-#endif
 
             /* Tell calling code that we have handled this event; the buck
              * stops here. */
