@@ -62,6 +62,7 @@
 #include "gnc-ui.h"
 #include "gnc-ui-util.h"
 #include "gnucash-sheet.h"
+#include "gnc-session.h"
 
 #include "gnc-split-reg.h"
 
@@ -200,7 +201,7 @@ sxed_confirmed_cancel(GncSxEditorDialog *sxed)
         const char *sx_changed_msg =
             _( "This Scheduled Transaction has changed; are you "
                "sure you want to cancel?" );
-        if (!gnc_verify_dialog(sxed->dialog, FALSE, "%s", sx_changed_msg))
+        if (!gnc_verify_dialog (GTK_WINDOW (sxed->dialog), FALSE, "%s", sx_changed_msg))
         {
             return FALSE;
         }
@@ -490,7 +491,7 @@ gnc_sxed_check_names (GncSxEditorDialog *sxed)
     {
         const char *sx_has_no_name_msg =
             _( "Please name the Scheduled Transaction." );
-        gnc_error_dialog( sxed->dialog, "%s", sx_has_no_name_msg );
+        gnc_error_dialog (GTK_WINDOW (sxed->dialog), "%s", sx_has_no_name_msg );
         g_free( name );
         return FALSE;
 
@@ -517,7 +518,7 @@ gnc_sxed_check_names (GncSxEditorDialog *sxed)
         const char *sx_has_existing_name_msg =
             _("A Scheduled Transaction with the name \"%s\" already exists. "
               "Are you sure you want to name this one the same?");
-        if (!gnc_verify_dialog (sxed->dialog, FALSE,
+        if (!gnc_verify_dialog (GTK_WINDOW (sxed->dialog), FALSE,
                                 sx_has_existing_name_msg, name))
         {
             g_free (name);
@@ -540,7 +541,7 @@ gnc_sxed_check_endpoint (GncSxEditorDialog *sxed)
     {
         const char *sx_end_spec_msg =
             _("Please provide a valid end selection.");
-        gnc_error_dialog (sxed->dialog, "%s", sx_end_spec_msg);
+        gnc_error_dialog (GTK_WINDOW (sxed->dialog), "%s", sx_end_spec_msg);
         return FALSE;
     }
 
@@ -555,7 +556,7 @@ gnc_sxed_check_endpoint (GncSxEditorDialog *sxed)
         {
             const char *sx_occur_count_zero_msg =
                 _("There must be some number of occurrences.");
-            gnc_error_dialog (sxed->dialog, "%s", sx_occur_count_zero_msg);
+            gnc_error_dialog (GTK_WINDOW (sxed->dialog), "%s", sx_occur_count_zero_msg);
             return FALSE;
         }
 
@@ -564,7 +565,7 @@ gnc_sxed_check_endpoint (GncSxEditorDialog *sxed)
             const char *sx_occur_counts_wrong_msg =
                 _("The number of remaining occurrences (%d) is greater than "
                   "the number of total occurrences (%d).");
-            gnc_error_dialog (sxed->dialog, sx_occur_counts_wrong_msg,
+            gnc_error_dialog (GTK_WINDOW (sxed->dialog), sx_occur_counts_wrong_msg,
                               rem, occur);
             return FALSE;
         }
@@ -593,7 +594,7 @@ gnc_sxed_check_endpoint (GncSxEditorDialog *sxed)
         const char *invalid_sx_check_msg =
             _("You have attempted to create a Scheduled Transaction which "
               "will never run. Do you really want to do this?");
-        if (!gnc_verify_dialog(sxed->dialog, FALSE,
+        if (!gnc_verify_dialog (GTK_WINDOW (sxed->dialog), FALSE,
                                "%s", invalid_sx_check_msg))
             return FALSE;
     }
@@ -612,7 +613,7 @@ gnc_sxed_check_autocreate (GncSxEditorDialog *sxed, int ttVarCount,
 
     if (((ttVarCount > 0) || multi_commodity) && autocreateState)
     {
-        gnc_warning_dialog(sxed->dialog, "%s",
+        gnc_warning_dialog(GTK_WINDOW (sxed->dialog), "%s",
                            _("Scheduled Transactions with variables "
                              "or involving more than one commodity "
                              "cannot be automatically created."));
@@ -623,7 +624,7 @@ gnc_sxed_check_autocreate (GncSxEditorDialog *sxed, int ttVarCount,
      * only valid if there's actually a transaction to create. */
     if (autocreateState && splitCount == 0)
     {
-        gnc_warning_dialog(sxed->dialog, "%s",
+        gnc_warning_dialog(GTK_WINDOW (sxed->dialog), "%s",
                            _("Scheduled Transactions without a template "
                              "transaction cannot be automatically created.") );
         return FALSE;
@@ -636,14 +637,16 @@ gnc_sxed_split_check_account (GncSxEditorDialog *sxed, Split *s,
                      gnc_commodity *base_cmdty, gboolean *multi_cmdty)
 {
     gnc_commodity *split_cmdty = NULL;
-    gnc_numeric split_amount = gnc_numeric_zero ();
+    gnc_numeric split_amount;
     Account *acct = NULL;
     GncGUID *acct_guid = NULL;
     qof_instance_get (QOF_INSTANCE (s),
                       "sx-account", &acct_guid,
                       NULL);
     acct = xaccAccountLookup (acct_guid, gnc_get_current_book ());
-    if (acct == NULL)
+    guid_free (acct_guid);
+    // If the split is being destroyed always return TRUE.
+    if (acct == NULL && !qof_instance_get_destroying(s))
         return FALSE;
     split_cmdty = xaccAccountGetCommodity(acct);
     split_amount = xaccSplitGetAmount(s);
@@ -672,7 +675,7 @@ gnc_sxed_split_calculate_formula (GncSxEditorDialog *sxed, Split *s,
     {
         gchar *err = g_strdup_printf (_("Couldn't parse %s for split \"%s\"."),
                                       key, xaccSplitGetMemo (s));
-        gnc_error_dialog (GTK_WIDGET(sxed->dialog), "%s", err);
+        gnc_error_dialog (GTK_WINDOW (sxed->dialog), "%s", err);
         g_free (err);
 
         return FALSE;
@@ -870,7 +873,7 @@ gnc_sxed_check_consistent( GncSxEditorDialog *sxed )
         const char *msg =
             _("The Scheduled Transaction Editor cannot automatically "
               "balance this transaction. Should it still be entered?");
-        if (!gnc_verify_dialog (sxed->dialog, FALSE, "%s", msg))
+        if (!gnc_verify_dialog (GTK_WINDOW (sxed->dialog), FALSE, "%s", msg))
             return FALSE;
     }
 
@@ -961,7 +964,7 @@ gnc_sxed_save_sx( GncSxEditorDialog *sxed )
 
         autocreateState = gtk_toggle_button_get_active( sxed->autocreateOpt );
         notifyState = gtk_toggle_button_get_active( sxed->notifyOpt );
-        /* "Notify" only makes sense if AutoCreate is actived;
+        /* "Notify" only makes sense if AutoCreate is activated;
          * enforce that here. */
         xaccSchedXactionSetAutoCreate( sxed->sx,
                                        autocreateState,
@@ -1114,13 +1117,14 @@ sxed_delete_event( GtkWidget *widget, GdkEvent *event, gpointer ud )
  * Create the Schedule Editor Dialog *
  ************************************/
 GncSxEditorDialog *
-gnc_ui_scheduled_xaction_editor_dialog_create (SchedXaction *sx,
-					       gboolean newSX)
+gnc_ui_scheduled_xaction_editor_dialog_create (GtkWindow *parent, 
+    SchedXaction *sx, gboolean newSX)
 {
     GncSxEditorDialog *sxed;
     GtkBuilder *builder;
     GtkWidget *button;
     int i;
+    int id;
     GList *dlgExists = NULL;
 
     static struct widgetSignalCallback
@@ -1190,14 +1194,16 @@ gnc_ui_scheduled_xaction_editor_dialog_create (SchedXaction *sx,
     sxed->endCountSpin = GTK_ENTRY(gtk_builder_get_object (builder, "end_spin"));
     sxed->endRemainSpin = GTK_ENTRY(gtk_builder_get_object (builder, "remain_spin"));
 
-    // Set the style context for this dialog so it can be easily manipulated with css
-    gnc_widget_set_style_context (GTK_WIDGET(sxed->dialog), "GncSxEditorDialog");
+    // Set the name of this dialog so it can be easily manipulated with css
+    gtk_widget_set_name (GTK_WIDGET(sxed->dialog), "gnc-id-sx-editor");
+    gnc_widget_style_context_add_class (GTK_WIDGET(sxed->dialog), "gnc-class-sx");
+   
+    gtk_window_set_transient_for (GTK_WINDOW (sxed->dialog), parent);
 
     /* Setup the end-date GNC widget */
     {
         GtkWidget *endDateBox = GTK_WIDGET(gtk_builder_get_object (builder, "editor_end_date_box"));
-        sxed->endDateEntry = GNC_DATE_EDIT(gnc_date_edit_new (gnc_time (NULL),
-							      FALSE, FALSE));
+        sxed->endDateEntry = GNC_DATE_EDIT(gnc_date_edit_new (gnc_time (NULL), FALSE, FALSE));
         gtk_widget_show(GTK_WIDGET(sxed->endDateEntry));
         g_signal_connect( sxed->endDateEntry, "date-changed",
                           G_CALLBACK( sxed_excal_update_adapt_cb ), sxed );
@@ -1205,10 +1211,12 @@ gnc_ui_scheduled_xaction_editor_dialog_create (SchedXaction *sx,
                             TRUE, TRUE, 0 );
     }
 
-    gnc_register_gui_component( DIALOG_SCHEDXACTION_EDITOR_CM_CLASS,
-                                NULL, /* no refresh handler */
-                                sxed_close_handler,
-                                sxed );
+    id = gnc_register_gui_component( DIALOG_SCHEDXACTION_EDITOR_CM_CLASS,
+                                     NULL, /* no refresh handler */
+                                     sxed_close_handler,
+                                     sxed );
+    // This ensure this dialog is closed when the session is closed.
+    gnc_gui_component_set_session (id, gnc_get_current_session());
 
     g_signal_connect( sxed->dialog, "delete_event",
                       G_CALLBACK(sxed_delete_event), sxed );
@@ -1239,7 +1247,7 @@ gnc_ui_scheduled_xaction_editor_dialog_create (SchedXaction *sx,
 
     /* Allow resize */
     gtk_window_set_resizable (GTK_WINDOW(sxed->dialog), TRUE);
-    gnc_restore_window_size(GNC_PREFS_GROUP_SXED, GTK_WINDOW(sxed->dialog));
+    gnc_restore_window_size(GNC_PREFS_GROUP_SXED, GTK_WINDOW(sxed->dialog), parent);
 
     /* create the frequency-selection widget and example [dense-]calendar. */
     schedXact_editor_create_freq_sel( sxed );
@@ -1557,7 +1565,7 @@ gnc_sxed_reg_check_close(GncSxEditorDialog *sxed)
         return;
     }
 
-    if (gnc_verify_dialog(sxed->dialog, TRUE, "%s", message))
+    if (gnc_verify_dialog (GTK_WINDOW (sxed->dialog), TRUE, "%s", message))
     {
         if ( !gnc_split_register_save( reg, TRUE ) )
             return;
@@ -1591,7 +1599,6 @@ gnc_sxed_update_cal(GncSxEditorDialog *sxed)
     g_date_clear(&start_date, 1);
 
     gnc_frequency_save_to_recurrence(sxed->gncfreq, &recurrences, &start_date);
-    g_date_subtract_days(&start_date, 1);
     recurrenceListNextInstance(recurrences, &start_date, &first_date);
 
     /* Deal with the fact that this SX may have been run before [the
@@ -1602,10 +1609,10 @@ gnc_sxed_update_cal(GncSxEditorDialog *sxed)
         last_sx_inst = xaccSchedXactionGetLastOccurDate(sxed->sx);
         if (g_date_valid(last_sx_inst)
             && g_date_valid(&first_date)
-            && g_date_compare(last_sx_inst, &first_date) != 0)
+            && g_date_compare(last_sx_inst, &first_date) > 0)
         {
             /* last occurrence will be passed as initial date to update store
-             * later on as well */
+             * later on as well, but only if it's past first_date */
             start_date = *last_sx_inst;
             recurrenceListNextInstance(recurrences, &start_date, &first_date);
         }
@@ -1714,6 +1721,7 @@ typedef struct _acct_deletion_handler_data
 {
     GList *affected_sxes;
     GtkWidget *dialog;
+    GtkWindow *parent;
 } acct_deletion_handler_data;
 
 
@@ -1726,8 +1734,8 @@ _open_editors(GtkDialog *dialog, gint response_code, gpointer data)
         GList *sx_iter;
         for (sx_iter = adhd->affected_sxes; sx_iter; sx_iter = sx_iter->next)
         {
-            gnc_ui_scheduled_xaction_editor_dialog_create((SchedXaction*)sx_iter->data,
-                                                          FALSE);
+            gnc_ui_scheduled_xaction_editor_dialog_create(GTK_WINDOW(adhd->parent),
+                (SchedXaction*)sx_iter->data, FALSE);
         }
     }
     g_list_free(adhd->affected_sxes);
@@ -1759,6 +1767,7 @@ _sx_engine_event_handler(QofInstance *ent, QofEventId event_type, gpointer user_
         acct_deletion_handler_data *data;
         GtkBuilder *builder;
         GtkWidget *dialog;
+        GtkWindow *parent;
         GtkListStore *name_list;
         GtkTreeView *list;
         GtkTreeViewColumn *name_column;
@@ -1768,6 +1777,9 @@ _sx_engine_event_handler(QofInstance *ent, QofEventId event_type, gpointer user_
         gnc_builder_add_from_file (builder, "dialog-sx.glade", "account_deletion_dialog");
 
         dialog = GTK_WIDGET(gtk_builder_get_object (builder, "account_deletion_dialog"));
+        parent = gnc_ui_get_main_window (NULL);
+
+        gtk_window_set_transient_for (GTK_WINDOW (dialog), parent);
 
         list = GTK_TREE_VIEW(gtk_builder_get_object (builder, "sx_list"));
 
@@ -1776,6 +1788,7 @@ _sx_engine_event_handler(QofInstance *ent, QofEventId event_type, gpointer user_
 
         data = (acct_deletion_handler_data*)g_new0(acct_deletion_handler_data, 1);
         data->dialog = dialog;
+        data->parent = parent;
         data->affected_sxes = affected_sxes;
         name_list = gtk_list_store_new(1, G_TYPE_STRING);
         for (sx_iter = affected_sxes; sx_iter != NULL; sx_iter = sx_iter->next)
@@ -1814,7 +1827,7 @@ gnc_ui_sx_initialize (void)
     _sx_engine_event_handler_id = qof_event_register_handler(_sx_engine_event_handler, NULL);
 
     gnc_hook_add_dangler(HOOK_BOOK_OPENED,
-                         (GFunc)gnc_sx_sxsincelast_book_opened, NULL);
+                         (GFunc)gnc_sx_sxsincelast_book_opened, NULL, NULL);
 
     /* Add page to preferences page for Scheduled Transactions */
     /* The parameters are; glade file, items to add from glade file - last being the dialog, preference tab name */
