@@ -514,7 +514,7 @@ gnc_sxed_check_consistent (GncSxEditorDialog2 *sxed)
 {
     gboolean multi_commodity = FALSE;
     gnc_commodity *base_cmdty = NULL;
-    gint ttVarCount, splitCount;
+    gint ttVarCount, splitCount = 0;
     GList *schedule = NULL;
 
     /* Do checks on validity and such, interrupting the user if
@@ -536,8 +536,6 @@ gnc_sxed_check_consistent (GncSxEditorDialog2 *sxed)
      *   right... ]
      */
 
-    ttVarCount = 0;
-    splitCount = 0;
     {
         static const int NUM_ITERS_WITH_VARS = 5;
         static const int NUM_ITERS_NO_VARS = 1;
@@ -617,6 +615,7 @@ gnc_sxed_check_consistent (GncSxEditorDialog2 *sxed)
 				  "sx-debit-formula", &debit_formula,
 				  NULL);
                 acct = xaccAccountLookup( acct_guid, gnc_get_current_book ());
+                guid_free (acct_guid);
                 split_cmdty = xaccAccountGetCommodity(acct);
                 if (base_cmdty == NULL)
                 {
@@ -934,7 +933,7 @@ gnc_sxed_save_sx (GncSxEditorDialog2 *sxed )
 
         autocreateState = gtk_toggle_button_get_active (sxed->autocreateOpt);
         notifyState = gtk_toggle_button_get_active (sxed->notifyOpt);
-        /* "Notify" only makes sense if AutoCreate is actived;
+        /* "Notify" only makes sense if AutoCreate is activated;
          * enforce that here. */
         xaccSchedXactionSetAutoCreate (sxed->sx,
                                        autocreateState,
@@ -1163,8 +1162,9 @@ gnc_ui_scheduled_xaction_editor_dialog_create2 (GtkWindow *parent,
     sxed->endCountSpin = GTK_ENTRY (gtk_builder_get_object (builder, "end_spin"));
     sxed->endRemainSpin = GTK_ENTRY (gtk_builder_get_object (builder, "remain_spin"));
 
-    // Set the style context for this dialog so it can be easily manipulated with css
-    gnc_widget_set_style_context (GTK_WIDGET(sxed->dialog), "GncSxEditorDialog");
+    // Set the name of this dialog so it can be easily manipulated with css
+    gtk_widget_set_name (GTK_WIDGET(sxed->dialog), "gnc-id-sx2-editor");
+    gnc_widget_style_context_add_class (GTK_WIDGET(sxed->dialog), "gnc-class-sx");
 
     gtk_window_set_transient_for (GTK_WINDOW (sxed->dialog), parent);
 
@@ -1213,7 +1213,7 @@ gnc_ui_scheduled_xaction_editor_dialog_create2 (GtkWindow *parent,
 
     /* Allow resize */
     gtk_window_set_resizable (GTK_WINDOW (sxed->dialog), TRUE);
-    gnc_restore_window_size (GNC_PREFS_GROUP_SXED, GTK_WINDOW (sxed->dialog));
+    gnc_restore_window_size (GNC_PREFS_GROUP_SXED, GTK_WINDOW (sxed->dialog), parent);
 
     /* create the frequency-selection widget and example [dense-]calendar. */
     schedXact_editor_create_freq_sel (sxed);
@@ -1772,9 +1772,9 @@ gnc_ui_sx_initialize2 (void) //FIXME need to remove the 2 when live
     _sx_engine_event_handler_id = qof_event_register_handler (_sx_engine_event_handler, NULL);
 
     gnc_hook_add_dangler (HOOK_BOOK_OPENED,
-                         (GFunc)gnc_sx_sxsincelast_book_opened, NULL);
+                          (GFunc)gnc_sx_sxsincelast_book_opened, NULL, NULL);
 
-    /* Add page to preferences page for Sheduled Transactions */
+    /* Add page to preferences page for Scheduled Transactions */
     /* The parameters are; glade file, items to add from glade file - last being the dialog, preference tab name */
     gnc_preferences_add_page ("dialog-sx.glade",
                               "create_days_adj,remind_days_adj,sx_prefs",
