@@ -256,7 +256,7 @@ sxftd_add_template_trans(SXFromTransInfo *sxfti)
     }
 
     if ( ! gnc_numeric_zero_p( runningBalance )
-            && !gnc_verify_dialog( (GtkWidget *)sxfti->dialog,
+            && !gnc_verify_dialog (GTK_WINDOW (sxfti->dialog),
                                    FALSE, "%s",
                                    _("The Scheduled Transaction Editor "
                                      "cannot automatically balance "
@@ -553,7 +553,7 @@ sxftd_ok_clicked(SXFromTransInfo *sxfti)
     {
         if ( sx_error == SXFTD_ERRNO_UNBALANCED_XACTION )
         {
-            gnc_error_dialog( gnc_ui_get_toplevel(), "%s",
+            gnc_error_dialog (GTK_WINDOW (sxfti->dialog), "%s",
                               _( "The Scheduled Transaction is unbalanced. "
                                  "You are strongly encouraged to correct this situation." ) );
         }
@@ -612,7 +612,8 @@ sxftd_advanced_clicked(SXFromTransInfo *sxfti)
     context = g_main_context_default();
     while (g_main_context_iteration(context, FALSE));
 
-    gnc_ui_scheduled_xaction_editor_dialog_create(sxfti->sx, TRUE /* newSX */);
+    gnc_ui_scheduled_xaction_editor_dialog_create(gnc_ui_get_main_window (sxfti->dialog),
+        sxfti->sx, TRUE /* newSX */);
     /* close ourself, since advanced editing entails us, and there are sync
      * issues otherwise. */
     sxftd_close(sxfti, FALSE);
@@ -752,7 +753,7 @@ sxftd_update_excal_adapt( GObject *o, gpointer ud )
  * Create the dialog *
  ********************/
 void
-gnc_sx_create_from_trans( Transaction *trans )
+gnc_sx_create_from_trans( GtkWindow *parent, Transaction *trans )
 {
 #ifndef __MINGW32__
     int errno;
@@ -768,8 +769,11 @@ gnc_sx_create_from_trans( Transaction *trans )
     gnc_builder_add_from_file  (builder , "dialog-sx.glade", "sx_from_real_trans_dialog");
     dialog = GTK_WIDGET(gtk_builder_get_object (builder, "sx_from_real_trans_dialog"));
 
-    // Set the style context for this dialog so it can be easily manipulated with css
-    gnc_widget_set_style_context (GTK_WIDGET(dialog), "GncSxFromTransDialog");
+    // Set the name of this dialog so it can be easily manipulated with css
+    gtk_widget_set_name (GTK_WIDGET(dialog), "gnc-id-sx-from-trans");
+    gnc_widget_style_context_add_class (GTK_WIDGET(dialog), "gnc-class-sx");
+
+    gtk_window_set_transient_for (GTK_WINDOW (dialog), parent);
 
     sxfti->builder = builder;
     sxfti->dialog = dialog;
@@ -781,12 +785,12 @@ gnc_sx_create_from_trans( Transaction *trans )
     {
         if ( errno == SXFTD_ERRNO_OPEN_XACTION )
         {
-            gnc_error_dialog( gnc_ui_get_toplevel(), "%s",
+            gnc_error_dialog (NULL, "%s",
                               _( "Cannot create a Scheduled Transaction "
                                  "from a Transaction currently "
                                  "being edited. Please Enter the "
                                  "Transaction before Scheduling." ) );
-            sxftd_close( sxfti, TRUE );
+            sxftd_destroy (NULL, sxfti);
             return;
         }
         else
