@@ -43,8 +43,8 @@
 #include "gnc-uri-utils.h"
 #include "gnc-window.h"
 #include "dialog-utils.h"
-#include "dialog-assoc.h"
-#include "dialog-assoc-utils.h"
+#include "dialog-doclink.h"
+#include "dialog-doclink-utils.h"
 #include "gncInvoice.h"
 
 /* This static indicates the debugging module that this .o belongs to.  */
@@ -88,9 +88,9 @@ static void gnc_plugin_page_invoice_cmd_duplicateEntry (GtkAction *action, GncPl
 static void gnc_plugin_page_invoice_cmd_pay_invoice (GtkAction *action, GncPluginPageInvoice *plugin_page);
 static void gnc_plugin_page_invoice_cmd_save_layout (GtkAction *action, GncPluginPageInvoice *plugin_page);
 static void gnc_plugin_page_invoice_cmd_reset_layout (GtkAction *action, GncPluginPageInvoice *plugin_page);
-static void gnc_plugin_page_invoice_cmd_associate (GtkAction *action, GncPluginPageInvoice *plugin_page);
-static void gnc_plugin_page_invoice_cmd_associate_remove (GtkAction *action, GncPluginPageInvoice *plugin_page);
-static void gnc_plugin_page_invoice_cmd_associate_open (GtkAction *action, GncPluginPageInvoice *plugin_page);
+static void gnc_plugin_page_invoice_cmd_link (GtkAction *action, GncPluginPageInvoice *plugin_page);
+static void gnc_plugin_page_invoice_cmd_link_remove (GtkAction *action, GncPluginPageInvoice *plugin_page);
+static void gnc_plugin_page_invoice_cmd_link_open (GtkAction *action, GncPluginPageInvoice *plugin_page);
 static void gnc_plugin_page_invoice_cmd_company_report (GtkAction *action, GncPluginPageInvoice *plugin_page);
 
 static void gnc_plugin_page_redraw_help_cb( GnucashRegister *gsr, GncPluginPageInvoice *invoice_page );
@@ -218,19 +218,14 @@ static GtkActionEntry gnc_plugin_page_invoice_actions [] =
         G_CALLBACK (gnc_plugin_page_invoice_cmd_new_invoice)
     },
     {
-        "BusinessAssociationAction", NULL, "_Update Association for Invoice", NULL,
-        "Update Association for current Invoice",
-        G_CALLBACK (gnc_plugin_page_invoice_cmd_associate)
+        "BusinessLinkAction", NULL, "_Manage Document Link...", NULL,
+        "Manage link of an external document to this item.",
+        G_CALLBACK (gnc_plugin_page_invoice_cmd_link)
     },
     {
-        "BusinessAssociationOpenAction", NULL, "_Open Association for Invoice", NULL,
-        "Open Association for current Invoice",
-        G_CALLBACK (gnc_plugin_page_invoice_cmd_associate_open)
-    },
-    {
-        "BusinessAssociationRemoveAction", NULL, "_Remove Association from Invoice", NULL,
-        "Remove Association from Invoice",
-        G_CALLBACK (gnc_plugin_page_invoice_cmd_associate_remove)
+        "BusinessLinkOpenAction", NULL, "_Open Linked Document", NULL,
+        "Open the linked document",
+        G_CALLBACK (gnc_plugin_page_invoice_cmd_link_open)
     },
     {
         "ToolsProcessPaymentAction", GNC_ICON_INVOICE_PAY, "_Pay Invoice", NULL,
@@ -265,8 +260,7 @@ static const gchar *invoice_book_readwrite_actions[] =
     "EditDuplicateInvoiceAction",
     "BusinessNewInvoiceAction",
     "ToolsProcessPaymentAction",
-    "BusinessAssociationAction",
-    "BusinessAssociationRemoveAction",
+    "BusinessLinkAction",
     NULL
 };
 
@@ -306,9 +300,8 @@ static action_toolbar_labels invoice_action_labels[] =
     {"EditUnpostInvoiceAction", N_("_Unpost Invoice")},
     {"BusinessNewInvoiceAction", N_("New _Invoice")},
     {"ToolsProcessPaymentAction", N_("_Pay Invoice")},
-    {"BusinessAssociationAction", N_("_Update Association for Invoice")},
-    {"BusinessAssociationOpenAction", N_("_Open Association for Invoice")},
-    {"BusinessAssociationRemoveAction", N_("_Remove Association from Invoice")},
+    {"BusinessLinkAction", N_("_Manage Document Link...")},
+    {"BusinessLinkOpenAction", N_("_Open Linked Document")},
     {NULL, NULL},
 };
 
@@ -328,9 +321,8 @@ static action_toolbar_labels bill_action_labels[] =
     {"EditUnpostInvoiceAction", N_("_Unpost Bill")},
     {"BusinessNewInvoiceAction", N_("New _Bill")},
     {"ToolsProcessPaymentAction", N_("_Pay Bill")},
-    {"BusinessAssociationAction", N_("_Update Association for Bill")},
-    {"BusinessAssociationOpenAction", N_("_Open Association for Bill")},
-    {"BusinessAssociationRemoveAction", N_("_Remove Association from Bill")},
+    {"BusinessLinkAction", N_("_Manage Document Link...")},
+    {"BusinessLinkOpenAction", N_("_Open Linked Document")},
     {NULL, NULL},
 };
 
@@ -350,9 +342,8 @@ static action_toolbar_labels voucher_action_labels[] =
     {"EditUnpostInvoiceAction", N_("_Unpost Voucher")},
     {"BusinessNewInvoiceAction", N_("New _Voucher")},
     {"ToolsProcessPaymentAction", N_("_Pay Voucher")},
-    {"BusinessAssociationAction", N_("_Update Association for Voucher")},
-    {"BusinessAssociationOpenAction", N_("_Open Association for Voucher")},
-    {"BusinessAssociationRemoveAction", N_("_Remove Association from Voucher")},
+    {"BusinessLinkAction", N_("_Manage Document Link...")},
+    {"BusinessLinkOpenAction", N_("_Open Linked Document")},
     {NULL, NULL},
 };
 
@@ -372,9 +363,8 @@ static action_toolbar_labels creditnote_action_labels[] =
     {"EditUnpostInvoiceAction", N_("_Unpost Credit Note")},
     {"BusinessNewInvoiceAction", N_("New _Credit Note")},
     {"ToolsProcessPaymentAction", N_("_Pay Credit Note")},
-    {"BusinessAssociationAction", N_("_Update Association for Credit Note")},
-    {"BusinessAssociationOpenAction", N_("_Open Association for Credit Note")},
-    {"BusinessAssociationRemoveAction", N_("_Remove Association from Credit Note")},
+    {"BusinessLinkAction", N_("_Manage Document Link...")},
+    {"BusinessLinkOpenAction", N_("_Open Linked Document")},
     {NULL, NULL},
 };
 
@@ -389,9 +379,8 @@ static action_toolbar_labels invoice_action_tooltips[] = {
     {"BlankEntryAction", N_("Move to the blank entry at the bottom of the invoice")},
     {"ToolsProcessPaymentAction", N_("Enter a payment for the owner of this invoice") },
     {"ReportsCompanyReportAction", N_("Open a company report window for the owner of this invoice") },
-    {"BusinessAssociationAction", N_("Update Association for current invoice")},
-    {"BusinessAssociationOpenAction", N_("Open Association for current invoice")},
-    {"BusinessAssociationRemoveAction", N_("Remove Association from invoice")},
+    {"BusinessLinkAction", N_("Manage Document Link")},
+    {"BusinessLinkOpenAction", N_("Open Linked Document")},
     {NULL, NULL},
 };
 
@@ -411,9 +400,8 @@ static action_toolbar_labels bill_action_tooltips[] = {
     {"BlankEntryAction", N_("Move to the blank entry at the bottom of the bill")},
     {"ToolsProcessPaymentAction", N_("Enter a payment for the owner of this bill") },
     {"ReportsCompanyReportAction", N_("Open a company report window for the owner of this bill") },
-    {"BusinessAssociationAction", N_("Update Association for current bill")},
-    {"BusinessAssociationOpenAction", N_("Open Association for current bill")},
-    {"BusinessAssociationRemoveAction", N_("Remove Association from bill")},
+    {"BusinessLinkAction", N_("Manage Document Link")},
+    {"BusinessLinkOpenAction", N_("Open Linked Document")},
     {NULL, NULL},
 };
 
@@ -433,9 +421,8 @@ static action_toolbar_labels voucher_action_tooltips[] = {
     {"BlankEntryAction", N_("Move to the blank entry at the bottom of the voucher")},
     {"ToolsProcessPaymentAction", N_("Enter a payment for the owner of this voucher") },
     {"ReportsCompanyReportAction", N_("Open a company report window for the owner of this voucher") },
-    {"BusinessAssociationAction", N_("Update Association for current voucher")},
-    {"BusinessAssociationOpenAction", N_("Open Association for current voucher")},
-    {"BusinessAssociationRemoveAction", N_("Remove Association from voucher")},
+    {"BusinessLinkAction", N_("Manage Document Link")},
+    {"BusinessLinkOpenAction", N_("Open Linked Document")},
     {NULL, NULL},
 };
 
@@ -455,9 +442,8 @@ static action_toolbar_labels creditnote_action_tooltips[] = {
     {"BlankEntryAction", N_("Move to the blank entry at the bottom of the credit note")},
     {"ToolsProcessPaymentAction", N_("Enter a payment for the owner of this credit note") },
     {"ReportsCompanyReportAction", N_("Open a company report window for the owner of this credit note") },
-    {"BusinessAssociationAction", N_("Update Association for credit note")},
-    {"BusinessAssociationOpenAction", N_("Open Association for credit note")},
-    {"BusinessAssociationRemoveAction", N_("Remove Association from credit note")},
+    {"BusinessLinkAction", N_("_Manage Document Link...")},
+    {"BusinessLinkOpenAction", N_("Open Linked Document")},
     {NULL, NULL},
 };
 
@@ -616,13 +602,11 @@ gnc_plugin_page_invoice_finalize (GObject *object)
 }
 
 static void
-update_assoc_actions (GncPluginPage *plugin_page, gboolean has_uri)
+update_doclink_actions (GncPluginPage *plugin_page, gboolean has_uri)
 {
     GtkAction *uri_action;
 
-    uri_action = gnc_plugin_page_get_action (GNC_PLUGIN_PAGE(plugin_page), "BusinessAssociationOpenAction");
-    gtk_action_set_sensitive (uri_action, has_uri);
-    uri_action = gnc_plugin_page_get_action (GNC_PLUGIN_PAGE(plugin_page), "BusinessAssociationRemoveAction");
+    uri_action = gnc_plugin_page_get_action (GNC_PLUGIN_PAGE(plugin_page), "BusinessLinkOpenAction");
     gtk_action_set_sensitive (uri_action, has_uri);
 }
 
@@ -757,12 +741,12 @@ gnc_plugin_page_invoice_update_menus (GncPluginPage *page, gboolean is_posted, g
     /* update the layout action tooltips */
     gnc_plugin_page_invoice_action_update (action_group, tooltip_layout_list, (void*)gtk_action_set_tooltip);
 
-    // update association buttons
+    // update doclink buttons
     invoice = gnc_invoice_window_get_invoice (priv->iw);
-    if (gncInvoiceGetAssociation (invoice))
+    if (gncInvoiceGetDocLink (invoice))
         has_uri = TRUE;
 
-    update_assoc_actions (page, has_uri);
+    update_doclink_actions (page, has_uri);
 }
 
 
@@ -1355,7 +1339,7 @@ gnc_plugin_page_invoice_cmd_reset_layout (GtkAction *action,
 }
 
 static void
-gnc_plugin_page_invoice_cmd_associate (GtkAction *action,
+gnc_plugin_page_invoice_cmd_link (GtkAction *action,
         GncPluginPageInvoice *plugin_page)
 {
     GncPluginPageInvoicePrivate *priv;
@@ -1372,46 +1356,49 @@ gnc_plugin_page_invoice_cmd_associate (GtkAction *action,
     parent = GTK_WINDOW(gnc_plugin_page_get_window (GNC_PLUGIN_PAGE(plugin_page)));
 
     invoice = gnc_invoice_window_get_invoice (priv->iw);
-    uri = gncInvoiceGetAssociation (invoice);
+    uri = gncInvoiceGetDocLink (invoice);
 
-    ret_uri = gnc_assoc_get_uri_dialog (parent, _("Change a Business Association"), uri);
+    ret_uri = gnc_doclink_get_uri_dialog (parent, _("Manage Document Link"), uri);
 
     if (ret_uri && g_strcmp0 (uri, ret_uri) != 0)
     {
-        GtkWidget *assoc_link_button = gnc_invoice_window_get_assoc_link_button (priv->iw);
+        GtkWidget *doclink_button =
+            gnc_invoice_window_get_doclink_button (priv->iw);
 
-        if (assoc_link_button)
+        if (doclink_button)
         {
             if (g_strcmp0 (ret_uri, "") == 0)
-                gtk_widget_hide (GTK_WIDGET(assoc_link_button));
+                gtk_widget_hide (GTK_WIDGET(doclink_button));
             else
             {
-                gchar *display_uri = gnc_assoc_get_unescaped_just_uri (ret_uri);
-                gtk_link_button_set_uri (GTK_LINK_BUTTON(assoc_link_button), display_uri);
-                gtk_widget_show (GTK_WIDGET(assoc_link_button));
+                gchar *display_uri =
+                    gnc_doclink_get_unescaped_just_uri (ret_uri);
+                gtk_link_button_set_uri (GTK_LINK_BUTTON(doclink_button),
+                                         display_uri);
+                gtk_widget_show (GTK_WIDGET(doclink_button));
                 g_free (display_uri);
             }
         }
-        gncInvoiceSetAssociation (invoice, ret_uri);
+        gncInvoiceSetDocLink (invoice, ret_uri);
         has_uri = TRUE;
     }
 
     // update the menu actions
-    update_assoc_actions (GNC_PLUGIN_PAGE(plugin_page), has_uri);
+    update_doclink_actions (GNC_PLUGIN_PAGE(plugin_page), has_uri);
 
     g_free (ret_uri);
     LEAVE(" ");
 }
 
 static void
-gnc_plugin_page_invoice_cmd_associate_remove (GtkAction *action,
+gnc_plugin_page_invoice_cmd_link_remove (GtkAction *action,
         GncPluginPageInvoice *plugin_page)
 {
     GncPluginPageInvoicePrivate *priv;
     GtkWindow *parent;
     GtkAction *uri_action;
     GncInvoice *invoice;
-    GtkWidget *assoc_link_button;
+    GtkWidget *doclink_button;
 
     g_return_if_fail (GNC_IS_PLUGIN_PAGE_INVOICE(plugin_page));
     ENTER("(action %p, plugin_page %p)", action, plugin_page);
@@ -1419,21 +1406,21 @@ gnc_plugin_page_invoice_cmd_associate_remove (GtkAction *action,
     parent = GTK_WINDOW(gnc_plugin_page_get_window (GNC_PLUGIN_PAGE(plugin_page)));
 
     invoice = gnc_invoice_window_get_invoice (priv->iw);
-    gncInvoiceSetAssociation (invoice, "");
+    gncInvoiceSetDocLink (invoice, "");
 
-    assoc_link_button = gnc_invoice_window_get_assoc_link_button (priv->iw);
+    doclink_button = gnc_invoice_window_get_doclink_button (priv->iw);
 
-    if (assoc_link_button)
-        gtk_widget_hide (GTK_WIDGET(assoc_link_button));
+    if (doclink_button)
+        gtk_widget_hide (GTK_WIDGET(doclink_button));
 
     // update the menu actions
-    update_assoc_actions (GNC_PLUGIN_PAGE(plugin_page), FALSE);
+    update_doclink_actions (GNC_PLUGIN_PAGE(plugin_page), FALSE);
 
     LEAVE(" ");
 }
 
 static void
-gnc_plugin_page_invoice_cmd_associate_open (GtkAction *action,
+gnc_plugin_page_invoice_cmd_link_open (GtkAction *action,
         GncPluginPageInvoice *plugin_page)
 {
     GncPluginPageInvoicePrivate *priv;
@@ -1447,10 +1434,10 @@ gnc_plugin_page_invoice_cmd_associate_open (GtkAction *action,
     parent = GTK_WINDOW(gnc_plugin_page_get_window (GNC_PLUGIN_PAGE(plugin_page)));
 
     invoice = gnc_invoice_window_get_invoice (priv->iw);
-    uri = gncInvoiceGetAssociation (invoice);
+    uri = gncInvoiceGetDocLink (invoice);
 
     if (uri)
-        gnc_assoc_open_uri (parent, uri);
+        gnc_doclink_open_uri (parent, uri);
 
     LEAVE(" ");
 }
