@@ -75,12 +75,9 @@ typedef struct _ofx_info
     gint num_trans_processed;               // Number of transactions processed
     struct OfxStatementData* statement;     // Statement, if any
     gboolean run_reconcile;                 // If TRUE the reconcile window is opened after matching.
-    GList *created_commodites;
     GSList* file_list;                      // List of OFX files to import
 } ofx_info ;
 
-GList *ofx_created_commodites = NULL;
-
 /*
 int ofx_proc_status_cb(struct OfxStatusData data)
 {
@@ -290,8 +287,6 @@ int ofx_proc_security_cb(const struct OfxSecurityData data, void * security_user
             /* Remember the commodity */
             gnc_commodity_table_insert(gnc_get_current_commodities(), commodity);
 
-            /* Remember this new commodity for us as well */
-            info->created_commodites = g_list_prepend(info->created_commodites, commodity);
 	    g_free (commodity_namespace);
 
         }
@@ -1074,18 +1069,6 @@ gnc_ofx_process_next_file (GtkDialog *dialog, gpointer user_data)
     {
         // Final cleanup.
         g_free (info);
-        if (ofx_created_commodites)
-        {
-            /* FIXME: Present some result window about the newly created
-             * commodities */
-            g_warning ("Created %d new commodities during import", g_list_length(ofx_created_commodites));
-            g_list_free (ofx_created_commodites);
-            ofx_created_commodites = NULL;
-        }
-        else
-        {
-            //g_warning("No new commodities created");
-        }
     }
 }
 
@@ -1135,7 +1118,7 @@ reconcile_when_close_toggled_cb (GtkToggleButton *togglebutton, ofx_info* info)
 static void
 gnc_file_ofx_import_process_file (ofx_info* info)
 {
-    LibofxContextPtr libofx_context = libofx_get_new_context();
+    LibofxContextPtr libofx_context;
     char* filename = NULL;
     char * selected_filename = NULL;
     GtkWindow *parent = info->parent;
@@ -1144,6 +1127,7 @@ gnc_file_ofx_import_process_file (ofx_info* info)
         return;
 
     filename = info->file_list->data;
+    libofx_context = libofx_get_new_context();
 
 #ifdef G_OS_WIN32
     selected_filename = g_win32_locale_filename_from_utf8 (filename);
@@ -1167,6 +1151,9 @@ gnc_file_ofx_import_process_file (ofx_info* info)
     // Create the match dialog, and run the ofx file through the importer.
     info->gnc_ofx_importer_gui = gnc_gen_trans_list_new (GTK_WIDGET(parent), NULL, TRUE, 42, FALSE);
     libofx_proc_file (libofx_context, selected_filename, AUTODETECT);
+    
+    // Free the libofx context before recursing to process the next file
+    libofx_free_context(libofx_context);
 
     // See whether the view has anything in it and warn the user if not.
     if(gnc_gen_trans_list_empty (info->gnc_ofx_importer_gui))
@@ -1208,7 +1195,6 @@ void gnc_file_ofx_import (GtkWindow *parent)
     extern int ofx_STATUS_msg;
     GSList* selected_filenames = NULL;
     char *default_dir;
-    LibofxContextPtr libofx_context = libofx_get_new_context();
     GList *filters = NULL;
     GSList* iter = NULL;
     ofx_info* info = NULL;
@@ -1252,6 +1238,9 @@ void gnc_file_ofx_import (GtkWindow *parent)
         info = g_new(ofx_info,1);
         info->num_trans_processed = 0;
         info->statement = NULL;
+        info->last_investment_account = NULL;
+        info->last_import_account = NULL;
+        info->last_income_account = NULL;
         info->parent = parent;
         info->run_reconcile = FALSE;
         info->file_list = selected_filenames;
