@@ -25,6 +25,7 @@
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
 (use-modules (gnucash json builder))            ;for building JSON options
+(use-modules (srfi srfi-9))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;
@@ -106,26 +107,42 @@
 ;; width - pair
 ;; height - pair
 
-(define <html-chart>
-  (make-record-type "<html-chart>"
-                    '(width
-                      height
-                      chart-options
-                      currency-iso
-                      currency-symbol
-                      custom-x-axis-ticks?
-                      custom-y-axis-ticks?)))
+(define-record-type <html-chart>
+  (make-html-chart width height chart-options currency-iso
+                   currency-symbol custom-x-axis-ticks? custom-y-axis-ticks?)
+  html-chart?
+  (width html-chart-width html-chart-set-width)
+  (height html-chart-height html-chart-set-height)
+  (chart-options html-chart-chart-options html-chart-set-chart-options)
+  (currency-iso html-chart-currency-iso html-chart-set-currency-iso)
+  (currency-symbol html-chart-currency-symbol html-chart-set-currency-symbol)
+  (custom-x-axis-ticks? html-chart-custom-x-axis-ticks?
+                        html-chart-set-custom-x-axis-ticks?)
+  (custom-y-axis-ticks? html-chart-custom-y-axis-ticks?
+                        html-chart-set-custom-y-axis-ticks?))
 
-(define gnc:html-chart?
-  (record-predicate <html-chart>))
+(define gnc:make-html-chart-internal make-html-chart)
+(define gnc:html-chart? html-chart?)
+(define gnc:html-chart-width html-chart-width)
+(define gnc:html-chart-set-width! html-chart-set-width)
+(define gnc:html-chart-height html-chart-height)
+(define gnc:html-chart-set-height! html-chart-set-height)
+(define gnc:html-chart-currency-iso html-chart-currency-iso)
+(define gnc:html-chart-set-currency-iso! html-chart-set-currency-iso)
+(define gnc:html-chart-currency-symbol html-chart-currency-symbol)
+(define gnc:html-chart-set-currency-symbol! html-chart-set-currency-symbol)
+(define gnc:html-chart-custom-x-axis-ticks? html-chart-custom-x-axis-ticks?)
+(define gnc:html-chart-set-custom-x-axis-ticks?! html-chart-set-custom-x-axis-ticks?)
+(define gnc:html-chart-custom-y-axis-ticks? html-chart-custom-y-axis-ticks?)
+(define gnc:html-chart-set-custom-y-axis-ticks?! html-chart-set-custom-y-axis-ticks?)
+(define gnc:html-chart-get-options-internal html-chart-chart-options)
+(define gnc:html-chart-set-options-internal! html-chart-set-chart-options)
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;  <html-chart> class
 ;;  generate the <object> form for an html chart.
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
-(define gnc:make-html-chart-internal
-  (record-constructor <html-chart>))
 
 (define (gnc:make-html-chart)
   (gnc:make-html-chart-internal
@@ -169,7 +186,6 @@
                                                                      (cons 'display #t)
                                                                      (cons 'labelString "")))
                                                   (cons 'ticks (list
-                                                                (cons 'fontSize 12)
                                                                 (cons 'maxRotation 30))))
                                                  ;; the following another xAxis at the top
                                                  '((position . top)
@@ -188,8 +204,7 @@
                                                                      (cons 'display 1.5)
                                                                      (cons 'labelString "")))
                                                   (cons 'ticks (list
-                                                                (cons 'fontSize 10)
-                                                                (cons 'beginAtZero #t))))
+                                                                (cons 'beginAtZero #f))))
                                                  ;; the following another yAxis on the right
                                                  '((position . right)
                                                    (ticks . ((display . #f)))
@@ -198,7 +213,6 @@
                                                  ))))
                     (cons 'title (list
                                   (cons 'display #t)
-                                  (cons 'fontSize 16)
                                   (cons 'fontStyle "")
                                   (cons 'text ""))))))
    "XXX"     ;currency-iso
@@ -207,18 +221,6 @@
    #t        ;custom y-axis ticks?
    ))
 
-(define gnc:html-chart-width
-  (record-accessor <html-chart> 'width))
-
-(define gnc:html-chart-set-width!
-  (record-modifier <html-chart> 'width))
-
-(define gnc:html-chart-height
-  (record-accessor <html-chart> 'height))
-
-(define gnc:html-chart-set-height!
-  (record-modifier <html-chart> 'height))
-
 (define (gnc:html-chart-type chart)
   (gnc:html-chart-get chart '(type)))
 
@@ -288,12 +290,6 @@
 (define-public (gnc:html-chart-set-y-axis-label! chart label)
   (gnc:html-chart-set! chart '(options scales yAxes (0) scaleLabel labelString) label))
 
-(define gnc:html-chart-get-options-internal
-  (record-accessor <html-chart> 'chart-options))
-
-(define gnc:html-chart-set-options-internal!
-  (record-modifier <html-chart> 'chart-options))
-
 (define (gnc:html-chart-get chart path)
   (let ((options (gnc:html-chart-get-options-internal chart)))
     (nested-alist-get options path)))
@@ -304,30 +300,6 @@
     (nested-alist-set! options path val-vec)
     (gnc:html-chart-set-options-internal! chart options)))
 
-(define gnc:html-chart-currency-iso
-  (record-accessor <html-chart> 'currency-iso))
-
-(define gnc:html-chart-set-currency-iso!
-  (record-modifier <html-chart> 'currency-iso))
-
-(define gnc:html-chart-currency-symbol
-  (record-accessor <html-chart> 'currency-symbol))
-
-(define gnc:html-chart-set-currency-symbol!
-  (record-modifier <html-chart> 'currency-symbol))
-
-(define gnc:html-chart-custom-x-axis-ticks?
-  (record-accessor <html-chart> 'custom-x-axis-ticks?))
-
-(define-public gnc:html-chart-set-custom-x-axis-ticks?!
-  (record-modifier <html-chart> 'custom-x-axis-ticks?))
-
-(define gnc:html-chart-custom-y-axis-ticks?
-  (record-accessor <html-chart> 'custom-y-axis-ticks?))
-
-(define-public gnc:html-chart-set-custom-y-axis-ticks?!
-  (record-modifier <html-chart> 'custom-y-axis-ticks?))
-
 (define JS-Number-to-String "
 // The following snippet from MDN
 // https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Number/toLocaleString
@@ -373,6 +345,17 @@ Chart.pluginService.register({
   }
 })
 
+// copy font info from css into chartjs.
+bodyStyle = window.getComputedStyle (document.querySelector ('body'));
+Chart.defaults.global.defaultFontSize = parseInt (bodyStyle.fontSize);
+Chart.defaults.global.defaultFontFamily = bodyStyle.fontFamily;
+Chart.defaults.global.defaultFontStyle = bodyStyle.fontStyle;
+
+titleStyle = window.getComputedStyle (document.querySelector ('h3'));
+chartjsoptions.options.title.fontSize = parseInt (titleStyle.fontSize);
+chartjsoptions.options.title.fontFamily = titleStyle.fontFamily;
+chartjsoptions.options.title.fontStyle = titleStyle.fontStyle;
+
 document.getElementById(chartid).onclick = function(evt) {
   var activepoints = myChart.getElementAtEvent(evt);
   var anchor = document.getElementById(jumpid);
@@ -423,23 +406,25 @@ document.getElementById(chartid).onclick = function(evt) {
          (push (lambda (l) (set! retval (cons l retval))))
          ;; Use a unique chart-id for each chart. This prevents charts
          ;; clashing on multi-column reports
-         (id (guid-new-return)))
+         (id (symbol->string (gensym "chart"))))
 
     (push (gnc:html-js-include
            (gnc-path-find-localized-html-file "chartjs/Chart.bundle.min.js")))
 
+    ;; the following hidden h3 is used to query style and copy onto chartjs
+    (push "<h3 style='display:none'></h3>")
     (push (format #f "<div style='width:~a;height:~a;'>\n"
                   (size->str (gnc:html-chart-width chart))
                   (size->str (gnc:html-chart-height chart))))
     (push (format #f "<a id='jump-~a' href='' style='display:none'></a>\n" id))
-    (push (format #f "<canvas id='chart-~a'></canvas>\n" id))
+    (push (format #f "<canvas id=~s></canvas>\n" id))
     (push "</div>\n")
     (push (format #f "<script id='script-~a'>\n" id))
     (push (format #f "var curriso = ~s;\n" (gnc:html-chart-currency-iso chart)))
     (push (format #f "var currsym = ~s;\n" (gnc:html-chart-currency-symbol chart)))
-    (push (format #f "var chartid = 'chart-~a';\n" id))
+    (push (format #f "var chartid = ~s;\n" id))
     (push (format #f "var jumpid = 'jump-~a';\n" id))
-    (push (format #f "var loadstring = ~s;\n" (_ "Load")))
+    (push (format #f "var loadstring = ~s;\n" (G_ "Load")))
     (push (format #f "var chartjsoptions = ~a;\n\n"
                   (get-options-string chart)))
 
@@ -453,7 +438,6 @@ document.getElementById(chartid).onclick = function(evt) {
 
     (push "chartjsoptions.options.tooltips.callbacks.label = tooltipLabel;\n")
     (push "chartjsoptions.options.tooltips.callbacks.title = tooltipTitle;\n")
-    (push "Chart.defaults.global.defaultFontFamily = \"'Trebuchet MS', Arial, Helvetica, sans-serif\";\n")
     (push JS-setup)
 
     (push "var myChart = new Chart(chartid, chartjsoptions);\n")
