@@ -29,6 +29,7 @@
 (use-modules (sw_report))
 
 (use-modules (ice-9 match))
+(use-modules (srfi srfi-9))
 
 ; Export the swig-wrapped symbols in the public interface of this module
 (let ((i (module-public-interface (current-module))))
@@ -82,22 +83,54 @@
 (define gnc:optname-invoice-number (N_ "Invoice Number"))
 
 ;; A <report-template> represents one of the available report types.
-(define <report-template>
-  (make-record-type
-   "<report-template>"
-   ;; The data items in a report record
-   '(version name report-guid parent-type options-generator
-             options-cleanup-cb options-changed-cb
-             renderer in-menu? menu-path menu-name
-             menu-tip export-types export-thunk)))
+(define-record-type <report-template>
+  (make-new-record-template version name report-guid parent-type options-generator
+                            options-cleanup-cb options-changed-cb
+                            renderer in-menu? menu-path menu-name
+                            menu-tip export-types export-thunk)
+  report-template?
+  (version report-template-version)
+  (report-guid report-template-report-guid report-template-set-report-guid!)
+  (name report-template-name report-template-set-name)
+  (parent-type report-template-parent-type report-template-set-parent-type!)
+  (options-generator report-template-options-generator)
+  (options-cleanup-cb report-template-options-cleanup-cb)
+  (options-changed-cb report-template-options-changed-cb)
+  (renderer report-template-renderer)
+  (in-menu? report-template-in-menu?)
+  (menu-path report-template-menu-path)
+  (menu-name report-template-menu-name)
+  (menu-tip report-template-menu-tip)
+  (export-types report-template-export-types)
+  (export-thunk report-template-export-thunk))
+
+(define (make-report-template)
+  (make-new-record-template #f #f #f #f #f #f #f #f #t #f #f #f #f #f))
+(define gnc:report-template-version report-template-version)
+(define gnc:report-template-report-guid report-template-report-guid)
+(define gnc:report-template-set-report-guid! report-template-set-report-guid!)
+(define gnc:report-template-name report-template-name)
+(define gnc:report-template-set-name report-template-set-name)
+(define gnc:report-template-parent-type report-template-parent-type)
+(define gnc:report-template-set-parent-type! report-template-set-parent-type!)
+(define gnc:report-template-options-generator report-template-options-generator)
+(define gnc:report-template-options-cleanup-cb report-template-options-cleanup-cb)
+(define gnc:report-template-options-changed-cb report-template-options-changed-cb)
+(define gnc:report-template-renderer report-template-renderer)
+(define gnc:report-template-in-menu? report-template-in-menu?)
+(define gnc:report-template-menu-path report-template-menu-path)
+(define gnc:report-template-menu-name report-template-menu-name)
+(define gnc:report-template-menu-tip report-template-menu-tip)
+(define gnc:report-template-export-types report-template-export-types)
+(define gnc:report-template-export-thunk report-template-export-thunk)
 
 ;; define strings centrally to ease code clarity
 (define rpterr-dupe
-  (_ "One of your reports has a report-guid that is a duplicate. Please check the report system, especially your saved reports, for a report with this report-guid: "))
-(define rpterr-guid1 (_ "Wrong report definition: "))
-(define rpterr-guid2 (_ " Report is missing a GUID."))
+  (G_ "One of your reports has a report-guid that is a duplicate. Please check the report system, especially your saved reports, for a report with this report-guid: "))
+(define rpterr-guid1 (G_ "Wrong report definition: "))
+(define rpterr-guid2 (G_ " Report is missing a GUID."))
 (define rptwarn-legacy
-  (_ "Some reports stored in a legacy format were found. This format is not supported anymore so these reports may not have been restored properly."))
+  (G_ "Some reports stored in a legacy format were found. This format is not supported anymore so these reports may not have been restored properly."))
 (define (gui-error str)
   (if (gnucash-ui-is-running)
       (gnc-error-dialog '() str)
@@ -121,82 +154,34 @@ not found.")))
   ;; The renderer should be a function that accepts one argument, a
   ;; set of options, and generates the report. the renderer must
   ;; return as its final value an <html-document> object.
+  (define report-rec (make-report-template))
+  (define allowable-fields (record-type-fields <report-template>))
+  (define (not-a-field? fld) (not (memq fld allowable-fields)))
 
-  (let* ((report-rec (let loop ((report-rec (make-report-template)) (args args))
-                       (match args
-                         (() report-rec)
-                         ((field val . rest)
-                          ((record-modifier <report-template> field) report-rec val)
-                          (loop report-rec rest)))))
-         (report-guid (gnc:report-template-report-guid report-rec))
-         (report-name (gnc:report-template-name report-rec)))
-    (cond
+  (let loop ((args args))
+    (match args
+      (()
+       (let ((report-guid (gnc:report-template-report-guid report-rec))
+             (report-name (gnc:report-template-name report-rec)))
+         (cond
+          ;; missing report-guid: is an error
+          ((not report-guid)
+           (gui-error (string-append rpterr-guid1 report-name rpterr-guid2)))
 
-     ;; missing report-guid: is an error
-     ((not report-guid)
-      (gui-error (string-append rpterr-guid1 report-name rpterr-guid2)))
+          ;; dupe: report-guid is a duplicate
+          ((hash-ref *gnc:_report-templates_* report-guid)
+           (gui-error (string-append rpterr-dupe report-guid)))
 
-     ;; dupe: report-guid is a duplicate
-     ((hash-ref *gnc:_report-templates_* report-guid)
-      (gui-error (string-append rpterr-dupe report-guid)))
+          ;; good: new report definition, store into report-templates hash
+          (else
+           (hash-set! *gnc:_report-templates_* report-guid report-rec)))))
 
-     ;; good: new report definition, store into report-templates hash
-     (else
-      (hash-set! *gnc:_report-templates_* report-guid report-rec)))))
+      (((? not-a-field? fld) . _)
+       (gnc:error "gnc:define-report: " fld " is not a valid field"))
 
-(define gnc:report-template-version
-  (record-accessor <report-template> 'version))
-(define gnc:report-template-report-guid
-  (record-accessor <report-template> 'report-guid))
-(define gnc:report-template-set-report-guid!
-  (record-modifier <report-template> 'report-guid))
-(define gnc:report-template-name
-  (record-accessor <report-template> 'name))
-(define gnc:report-template-set-name
-  (record-modifier <report-template> 'name))
-(define gnc:report-template-parent-type
-  (record-accessor <report-template> 'parent-type))
-(define gnc:report-template-set-parent-type!
-  (record-modifier <report-template> 'parent-type))
-(define gnc:report-template-options-generator
-  (record-accessor <report-template> 'options-generator))
-(define gnc:report-template-options-cleanup-cb
-  (record-accessor <report-template> 'options-cleanup-cb))
-(define gnc:report-template-options-changed-cb
-  (record-accessor <report-template> 'options-changed-cb))
-(define gnc:report-template-renderer
-  (record-accessor <report-template> 'renderer))
-(define gnc:report-template-in-menu?
-  (record-accessor <report-template> 'in-menu?))
-(define gnc:report-template-menu-path
-  (record-accessor <report-template> 'menu-path))
-(define gnc:report-template-menu-name
-  (record-accessor <report-template> 'menu-name))
-(define gnc:report-template-menu-tip
-  (record-accessor <report-template> 'menu-tip))
-(define gnc:report-template-export-types
-  (record-accessor <report-template> 'export-types))
-(define gnc:report-template-export-thunk
-  (record-accessor <report-template> 'export-thunk))
-(define (make-report-template)
-  ((record-constructor <report-template>)
-   #f                         ;; version
-   #f                         ;; name
-   #f                         ;; report-guid
-   #f                         ;; parent-type (meaning guid of
-                              ;; report-template this template is
-                              ;; based on)
-   #f                         ;; options-generator
-   #f                         ;; options-cleanup-cb
-   #f                         ;; options-changed-cb
-   #f                         ;; renderer
-   #t                         ;; in-menu?
-   #f                         ;; menu-path
-   #f                         ;; menu-name
-   #f                         ;; menu-tip
-   #f                         ;; export-types
-   #f                         ;; export-thunk
-   ))
+      ((field val . rest)
+       ((record-modifier <report-template> field) report-rec val)
+       (loop rest)))))
 
 (define (gnc:report-template-new-options/report-guid template-id template-name)
   (let ((templ (hash-ref *gnc:_report-templates_* template-id)))
@@ -220,7 +205,7 @@ not found.")))
          (gnc:make-string-option
           gnc:pagename-general gnc:optname-reportname "0a"
           (N_ "Enter a descriptive name for this report.")
-          (_ (gnc:report-template-name report-template))))
+          (G_ (gnc:report-template-name report-template))))
         (stylesheet
          (gnc:make-multichoice-option
           gnc:pagename-general gnc:optname-stylesheet "0b"
@@ -232,7 +217,7 @@ not found.")))
               (string->symbol (gnc:html-style-sheet-name ss))
               (gnc:html-style-sheet-name ss)
               (string-append (gnc:html-style-sheet-name ss)
-                             " " (_ "stylesheet."))))
+                             " " (G_ "stylesheet."))))
            (gnc:get-html-style-sheets)))))
 
     (let ((options (if (procedure? generator)
@@ -250,69 +235,42 @@ not found.")))
       options)))
 
 ;; A <report> represents an instantiation of a particular report type.
-(define <report>
-  (make-record-type
-   "<report>"
-   '(type id options dirty? needs-save? editor-widget ctext custom-template)))
+(define-record-type <report>
+  (make-report type id options dirty? needs-save? editor-widget ctext custom-template)
+  report?
+  (type report-type report-set-type!)
+  (id report-id report-set-id!)
+  (options report-options report-set-options!)
+  (dirty? report-dirty? report-set-dirty?!)
+  (needs-save? report-needs-save? report-set-needs-save?!)
+  (editor-widget report-editor-widget report-set-editor-widget!)
+  (ctext report-ctext report-set-ctext!)
+  (custom-template report-custom-template report-set-custom-template!))
 
-(define gnc:report-type
-  (record-accessor <report> 'type))
-
-(define gnc:report-set-type!
-  (record-modifier <report> 'type))
-
-(define gnc:report-id
-  (record-accessor <report> 'id))
-
-(define gnc:report-set-id!
-  (record-modifier <report> 'id))
-
-(define gnc:report-options
-  (record-accessor <report> 'options))
-
-(define gnc:report-set-options!
-  (record-modifier <report> 'options))
-
-(define gnc:report-needs-save?
-  (record-accessor <report> 'needs-save?))
-
-(define gnc:report-set-needs-save?!
-  (record-modifier <report> 'needs-save?))
-
-(define gnc:report-dirty?
-  (record-accessor <report> 'dirty?))
-
-(define gnc:report-set-dirty?-internal!
-  (record-modifier <report> 'dirty?))
+(define gnc:report-type report-type)
+(define gnc:report-set-type! report-set-type!)
+(define gnc:report-id report-id)
+(define gnc:report-set-id! report-set-id!)
+(define gnc:report-options report-options)
+(define gnc:report-set-options! report-set-options!)
+(define gnc:report-needs-save? report-needs-save?)
+(define gnc:report-set-needs-save?! report-set-needs-save?!)
+(define gnc:report-dirty? report-dirty?)
+(define gnc:report-set-dirty?-internal! report-set-dirty?!)
+(define gnc:report-editor-widget report-editor-widget)
+(define gnc:report-set-editor-widget! report-set-editor-widget!)
+(define gnc:report-ctext report-ctext)
+(define gnc:report-set-ctext! report-set-ctext!)
+(define gnc:report-custom-template report-custom-template)
+(define gnc:report-set-custom-template! report-set-custom-template!)
 
 (define (gnc:report-set-dirty?! report val)
   (gnc:report-set-dirty?-internal! report val)
-  (let* ((template (hash-ref *gnc:_report-templates_*
-                             (gnc:report-type report)))
+  (let* ((template (hash-ref *gnc:_report-templates_* (gnc:report-type report)))
          (cb (gnc:report-template-options-changed-cb template)))
     (if (and cb (procedure? cb))
         (cb report))))
 
-(define gnc:report-editor-widget
-  (record-accessor <report> 'editor-widget))
-
-(define gnc:report-set-editor-widget!
-  (record-modifier <report> 'editor-widget))
-
-;; ctext is for caching the rendered html
-(define gnc:report-ctext
-  (record-accessor <report> 'ctext))
-
-(define gnc:report-set-ctext!
-  (record-modifier <report> 'ctext))
-
-(define gnc:report-custom-template
-  (record-accessor <report> 'custom-template))
-
-(define gnc:report-set-custom-template!
-  (record-modifier <report> 'custom-template))
-
-
 ;; gnc:make-report instantiates a report from a report-template.
 ;; The actual report is stored away in a hash-table -- only the id is returned.
 (define (gnc:make-report template-id . rest)
@@ -320,7 +278,7 @@ not found.")))
                            (hash-ref *gnc:_report-templates_* template-id)))
          (report-type (or template-parent template-id))
          (custom-template (if template-parent template-id ""))
-         (r ((record-constructor <report>)
+         (r (make-report
              report-type     ;; type
              #f              ;; id
              #f              ;; options
@@ -348,8 +306,7 @@ not found.")))
 
 (define (gnc:restore-report-by-guid id template-id template-name options)
   (if options
-      (let* ((r ((record-constructor <report>)
-                 template-id id options #t #t #f #f ""))
+      (let* ((r (make-report template-id id options #t #t #f #f ""))
              (report-id (gnc-report-add r)))
         (if (number? report-id)
             (gnc:report-set-id! r report-id))
@@ -361,8 +318,7 @@ not found.")))
 (define (gnc:restore-report-by-guid-with-custom-template
          id template-id template-name custom-template-id options)
   (if options
-      (let* ((r ((record-constructor <report>)
-                 template-id id options #t #t #f #f custom-template-id))
+      (let* ((r (make-report template-id id options #t #t #f #f custom-template-id))
              (report-id (gnc-report-add r)))
         (if (number? report-id)
             (gnc:report-set-id! r report-id))
@@ -773,31 +729,37 @@ not found.")))
       (gnc:report-template-set-name templ new-name)
       (gnc:save-all-reports))))
 
+;;
+;; gnucash-cli helper and exported functions
+;;
+
 (define (stderr-log tmpl . args)
   (apply format (current-error-port) tmpl args)
   #f)
 
-(define (template-export report template export-type output-file dry-run?)
+(define (template-export report template export-type dry-run?)
   (let* ((report-guid (gnc:report-template-report-guid template))
          (parent-template-guid (gnc:report-template-parent-type template))
-         (parent-template (hash-ref *gnc:_report-templates_* parent-template-guid))
-         (parent-export-thunk (gnc:report-template-export-thunk parent-template))
-         (parent-export-types (gnc:report-template-export-types parent-template)))
+         (template (if parent-template-guid
+                       (hash-ref *gnc:_report-templates_* parent-template-guid)
+                       template))
+         (export-thunk (gnc:report-template-export-thunk template))
+         (export-types (gnc:report-template-export-types template)))
 
     (cond
-     ((not parent-export-thunk) (stderr-log "Report ~s has no export code\n" report))
-     ((not parent-export-types) (stderr-log "Report ~s has no export-types\n" report))
-     ((not (assoc export-type parent-export-types))
+     ((not export-thunk) (stderr-log "Report ~s has no export code\n" report))
+     ((not export-types) (stderr-log "Report ~s has no export-types\n" report))
+     ((not (assoc export-type export-types))
       (stderr-log "Export-type disallowed: ~a. Allowed types: ~a\n"
-                  export-type (string-join (map car parent-export-types) ", ")))
-     ((not output-file) (stderr-log "No output file specified\n"))
+                  export-type (string-join (map car export-types) ", ")))
      (dry-run? #t)
      (else
       (display "Running export..." (current-error-port))
-      (parent-export-thunk
-       (gnc-report-find (gnc:make-report report-guid))
-       (assoc-ref parent-export-types export-type) output-file)
-      (display "done!\n" (current-error-port))))))
+      (let ((output (export-thunk
+                     (gnc-report-find (gnc:make-report report-guid))
+                     (assoc-ref export-types export-type))))
+        (display "done!\n" (current-error-port))
+        output)))))
 
 (define (reportname->templates report)
   (or (and=> (gnc:find-report-template report) list)
@@ -826,22 +788,30 @@ not found.")))
      (else
       (for-each
        (lambda (template)
-         (let* ((options-gen (gnc:report-template-options-generator template)))
-           (format port "\n* guid: ~a\n~a"
+         (let* ((options-gen (gnc:report-template-options-generator template))
+                (parent-guid (gnc:report-template-parent-type template))
+                (parent-template (and parent-guid
+                                      (hash-ref *gnc:_report-templates_* parent-guid)))
+                (export-types (gnc:report-template-export-types
+                               (or parent-template template))))
+           (format port "\n* name: ~a\n  guid: ~a\n~a~a~a"
+                   (gnc:report-template-name template)
                    (gnc:report-template-report-guid template)
+                   (if parent-template
+                       (format #f "  parent-template: ~a\n"
+                               (gnc:report-template-name parent-template))
+                       "")
+                   (if export-types
+                       (format #f "  export-types: ~a\n"
+                               (string-join (map car export-types) ", ")) "")
                    (gnc:html-render-options-changed (options-gen) #t))))
        templates)))))
 
-(define-public (gnc:cmdline-run-report report export-type output-file dry-run?)
+;; In: report - string matching reportname
+;; In: export-type - string matching export type (eg CSV TXF etc)
+;; Out: if args are valid and runs a single report: #t, otherwise: #f
+(define-public (gnc:cmdline-check-report report export-type)
   (let ((templates (reportname->templates report)))
-
-    (define (run-report output-port)
-      (display
-       (gnc:report-render-html
-        (gnc-report-find
-         (gnc:make-report
-          (gnc:report-template-report-guid (car templates)))) #t) output-port))
-
     (cond
      ((null? templates)
       (stderr-log "Cannot find ~s. Valid reports:\n" report)
@@ -854,11 +824,20 @@ not found.")))
       (stderr-log "\n"))
 
      (export-type (template-export report (car templates)
-                                   export-type output-file dry-run?))
-     (dry-run? #t)
-     (output-file
-      (format (current-error-port) "Saving report to ~a..." output-file)
-      (call-with-output-file output-file run-report)
-      (display "complete!\n" (current-error-port)))
-     (else
-      (run-report (current-output-port))))))
+                                   export-type #t))
+     (else #t))))
+
+;; In: report - string matching reportname
+;; In: export-type - string matching export type (eg CSV TXF etc)
+;; Out: if error, #f
+(define-public (gnc:cmdline-template-export report export-type)
+  (match (reportname->templates report)
+    ((template) (template-export report template export-type #f))
+    (_ (gnc:error report " does not match unique report") #f)))
+
+;; In: report - string matching reportname
+;; Out: a number, or #f if error
+(define-public (gnc:cmdline-get-report-id report)
+  (match (reportname->templates report)
+    ((template) (gnc:make-report (gnc:report-template-report-guid template)))
+    (_ (gnc:error report " does not match unique report") #f)))
