@@ -86,13 +86,13 @@
 (export gnc:account-anchor-text)
 (export gnc:split-anchor-text)
 (export gnc:transaction-anchor-text)
-(export gnc:transaction-association-anchor-text)
+(export gnc:transaction-doclink-anchor-text)
 (export gnc:report-anchor-text)
 (export gnc:make-report-anchor)
 (export gnc:html-account-anchor)
 (export gnc:html-split-anchor)
 (export gnc:html-transaction-anchor)
-(export gnc:html-transaction-association-anchor)
+(export gnc:html-transaction-doclink-anchor)
 (export gnc:html-price-anchor)
 (export gnc:customer-anchor-text)
 (export gnc:job-anchor-text)
@@ -275,6 +275,10 @@
 (export gnc:html-document-markup-start)
 (export gnc:html-document-markup-end)
 (export gnc:html-document-render-data)
+(export gnc:html-document-export-string)
+(export gnc:html-document-set-export-string)
+(export gnc:html-document-export-error)
+(export gnc:html-document-set-export-error)
 (export <html-object>)
 (export gnc:html-object?)
 (export gnc:make-html-object-internal)
@@ -534,6 +538,8 @@
 (export gnc:html-chart-currency-symbol)
 (export gnc:html-chart-set-currency-symbol!)
 (export gnc:html-chart-render)
+(export gnc:html-chart-set-custom-x-axis-ticks?!)
+(export gnc:html-chart-set-custom-y-axis-ticks?!)
 
 ;; html-table.scm
 
@@ -729,6 +735,7 @@
 ;; trep-engine.scm
 (export gnc:trep-options-generator)
 (export gnc:trep-renderer)
+(export gnc:lists->csv)
 
 ;; report-register-hooks.scm
 
