@@ -412,7 +412,7 @@
            ((null? column-list)
             #f)
 
-           ;; fwd-compatibility: the next cond may be removed in master
+           ;; fwd-compatibility for unreversed budgets
            ((and (eq? (car column-list) 'total) unreversed?)
             (let* ((bgt-total (maybe-negate
                                (gnc:get-account-periodlist-budget-value
@@ -423,7 +423,7 @@
                    (dif-total (- bgt-total act-total)))
               (loop (cdr column-list)
                     (disp-cols "total-number-cell" current-col
-                               bgt-total act-total dif-total))))
+                               bgt-total act-total dif-total #f))))
 
            ((eq? (car column-list) 'total)
             (let* ((bgt-total (gnc:get-account-periodlist-budget-value
@@ -438,12 +438,15 @@
                     (disp-cols "total-number-cell" current-col
                                bgt-total act-total dif-total #f))))
 
-           ;; fwd-compatibility: the next cond may be removed in master
+           ;; fwd-compatibility for unreversed budgets
            (unreversed?
             (let* ((period-list (cond
                                  ((list? (car column-list)) (car column-list))
                                  (accumulate? (iota (1+ (car column-list))))
                                  (else (list (car column-list)))))
+                   (note (and (= 1 (length period-list))
+                              (gnc-budget-get-account-period-note
+                               budget acct (car period-list))))
                    (bgt-val (maybe-negate
                              (gnc:get-account-periodlist-budget-value
                               budget acct period-list)))
@@ -453,7 +456,7 @@
                    (dif-val (- bgt-val act-val)))
               (loop (cdr column-list)
                     (disp-cols "number-cell" current-col
-                               bgt-val act-val dif-val))))
+                               bgt-val act-val dif-val note))))
 
            (else
             (let* ((period-list (cond
@@ -505,9 +508,9 @@
              html-table 0 current-col
              (cond
               ((eq? (car column-list) 'total)
-               (_ "Total"))
+               (G_ "Total"))
               ((list? (car column-list))
-               (format #f (_ "~a to ~a")
+               (format #f (G_ "~a to ~a")
                        (period-to-date-string (car (car column-list)))
                        (period-to-date-string (last (car column-list)))))
               (else
@@ -531,17 +534,17 @@
                 (gnc:html-table-set-cell/tag!
                  html-table 1 col0 "centered-label-cell"
                  ;; Translators: Abbreviation for "Budget" amount
-                 (_ "Bgt")))
+                 (G_ "Bgt")))
               (when show-actual?
                 (gnc:html-table-set-cell/tag!
                  html-table 1 col1 "centered-label-cell"
                  ;; Translators: Abbreviation for "Actual" amount
-                 (_ "Act")))
+                 (G_ "Act")))
               (when show-diff?
                 (gnc:html-table-set-cell/tag!
                  html-table 1 col2 "centered-label-cell"
                  ;; Translators: Abbreviation for "Difference" amount
-                 (_ "Diff")))
+                 (G_ "Diff")))
               (loop (cdr column-list)
                     col3))))))
 
@@ -771,7 +774,7 @@
                      ;; budget will report on budgeted and actual
                      ;; amounts from the beginning of budget, instead
                      ;; of only using the budget-period amounts.
-                     (if accumulate? (_ "using accumulated amounts")
+                     (if accumulate? (G_ "using accumulated amounts")
                          "")))
 
         ;; We do this in two steps: First the account names...  the
