@@ -26,6 +26,7 @@
 (define-module (gnucash reports standard category-barchart))
 (use-modules (srfi srfi-1))
 (use-modules (srfi srfi-9))
+(use-modules (srfi srfi-26))
 (use-modules (ice-9 match))
 (use-modules (gnucash engine))
 (use-modules (gnucash utilities))
@@ -212,7 +213,8 @@ developing over time"))
 ;; *really* complicated.
 
 (define (category-barchart-renderer report-obj reportname reportguid
-                                    account-types do-intervals? reverse-bal?)
+                                    account-types do-intervals? reverse-bal?
+                                    export-type)
   ;; A helper functions for looking up option values.
   (define (get-option section name)
     (gnc:option-value
@@ -301,9 +303,9 @@ developing over time"))
                ;; accordingly.
                (report-title
                 (case averaging-selection
-                  ((MonthDelta) (string-append report-title " " (_ "Monthly Average")))
-                  ((WeekDelta) (string-append report-title " " (_ "Weekly Average")))
-                  ((DayDelta) (string-append report-title " " (_ "Daily Average")))
+                  ((MonthDelta) (string-append report-title " " (G_ "Monthly Average")))
+                  ((WeekDelta) (string-append report-title " " (G_ "Weekly Average")))
+                  ((DayDelta) (string-append report-title " " (G_ "Daily Average")))
                   (else report-title)))
                (currency-frac (gnc-commodity-get-fraction report-currency))
                ;; This is the list of date intervals to calculate.
@@ -495,10 +497,11 @@ developing over time"))
            (and (not (null? all-data))
                 (not-all-zeros  (map cadr all-data)))
 
-           (let ((dates-list (if do-intervals?
-                                 (list-head dates-list (1- (length dates-list)))
-                                 dates-list))
-                 (date-string-list (map qof-print-date dates-list)))
+           (let* ((dates-list (if do-intervals?
+                                  (list-head dates-list (1- (length dates-list)))
+                                  dates-list))
+                  (date-string-list (map qof-print-date dates-list)))
+
              ;; Set chart title, subtitle etc.
 
              (gnc:html-chart-set-type!
@@ -508,8 +511,8 @@ developing over time"))
               chart (list report-title
                           (format #f
                                   (if do-intervals?
-                                      (_ "~a to ~a")
-                                      (_ "Balances ~a to ~a"))
+                                      (G_ "~a to ~a")
+                                      (G_ "Balances ~a to ~a"))
                                   (qof-print-date from-date-t64)
                                   (qof-print-date to-date-t64))))
 
@@ -531,7 +534,7 @@ developing over time"))
                                     (apply zip (map cadr finish)))))
                    (set! all-data
                      (append start
-                             (list (list (_ "Other") other-sum))))
+                             (list (list (G_ "Other") other-sum))))
                    (let* ((options (gnc:make-report-options reportguid)))
                      ;; now copy all the options
                      (gnc:options-copy-values
@@ -601,35 +604,28 @@ developing over time"))
              (when show-table?
                (let ((table (gnc:make-html-table))
                      (scu (gnc-commodity-get-fraction report-currency))
-                     (cols>1? (> (length all-data) 1)))
+                     (cols>1? (pair? (cdr all-data))))
 
                  (define (make-cell contents)
                    (gnc:make-html-table-cell/markup "number-cell" contents))
 
-                 (define (monetary-round mon)
-                   (gnc:make-gnc-monetary
-                    report-currency
-                    (gnc-numeric-convert
-                     (gnc:gnc-monetary-amount mon)
-                     scu GNC-HOW-RND-ROUND)))
-
                  (for-each
                   (lambda (date row)
                     (gnc:html-table-append-row!
-                     table (map make-cell (append (list date)
-                                                  (map monetary-round row)
-                                                  (if cols>1?
-                                                      (list
-                                                       (monetary-round
-                                                        (apply gnc:monetary+ row)))
-                                                      '())))))
+                     table
+                     (append (list (make-cell date))
+                             (map make-cell row)
+                             (if cols>1?
+                                 (list
+                                  (make-cell (apply gnc:monetary+ row)))
+                                 '()))))
                   date-string-list
                   (apply zip (map cadr all-data)))
 
                  (gnc:html-table-set-col-headers!
                   table
                   (append
-                   (list (_ "Date"))
+                   (list (G_ "Date"))
                    (map
                     (lambda (col)
                       (cond
@@ -638,10 +634,39 @@ developing over time"))
                        (else (xaccAccountGetName col))))
                     (map car all-data))
                    (if cols>1?
-                       (list (_ "Grand Total"))
+                       (list (G_ "Grand Total"))
                        '())))
 
-                 (gnc:html-document-add-object! document table))))
+                 (gnc:html-document-add-object! document table)))
+
+             (cond
+              ((eq? export-type 'csv)
+               (let ((iso-date (qof-date-format-get-string QOF-DATE-FORMAT-ISO)))
+                 (gnc:html-document-set-export-string
+                  document
+                  (gnc:lists->csv
+                   (cons (append
+                          (list (G_ "Date"))
+                          (map
+                           (lambda (col)
+                             (cond
+                              ((string? col) col)
+                              (show-fullname? (gnc-account-get-full-name col))
+                              (else (xaccAccountGetName col))))
+                           (map car all-data))
+                          (if (pair? (cdr all-data))
+                              (list (G_ "Grand Total"))
+                              '()))
+                         (map
+                          (lambda (date row)
+                            (append
+                             (list date)
+                             row
+                             (if (pair? (cdr all-data))
+                                 (list (apply gnc:monetary+ row))
+                                 '())))
+                          (map (cut gnc-print-time64 <> iso-date) dates-list)
+                          (apply zip (map cadr all-data))))))))))
 
            ;; else if empty data
            (gnc:html-document-add-object!
@@ -655,6 +680,9 @@ developing over time"))
          (gnc:html-make-no-account-warning
           report-title (gnc:report-id report-obj))))
 
+    (unless (gnc:html-document-export-string document)
+      (gnc:html-document-set-export-error document (G_ "No exportable data")))
+
     (gnc:report-finished)
     document))
 
@@ -671,9 +699,15 @@ developing over time"))
      'menu-name menuname
      'menu-tip menutip
      'options-generator (lambda () (options-generator account-types inc-exp?))
+     'export-types '(("CSV" . csv))
+     'export-thunk (lambda (report-obj export-type filename)
+                     (category-barchart-renderer
+                      report-obj reportname uuid account-types inc-exp? reverse-bal?
+                      export-type))
      'renderer (lambda (report-obj)
                  (category-barchart-renderer
-                  report-obj reportname uuid account-types inc-exp? reverse-bal?)))))
+                  report-obj reportname uuid account-types inc-exp? reverse-bal?
+                  #f)))))
  (list
   ;; reportname, account-types, inc-exp?,
   ;; menu-reportname, menu-tip, reverse-bal?, uuid
