@@ -60,17 +60,18 @@ copying this report to a spreadsheet for use in a mail merge."))
         (list (N_ "Address Email") "i" (N_ "Display Email."))
         (list (N_ "Active") "j" (N_ "Display Active status."))))
 
-(define no-APAR-account (_ "No valid A/Payable or A/Receivable \
+(define no-APAR-account (G_ "No valid A/Payable or A/Receivable \
 account found. Please ensure valid AP/AR account exists."))
 
-(define empty-APAR-accounts (_ "A/Payable or A/Receivable accounts \
+(define empty-APAR-accounts (G_ "A/Payable or A/Receivable accounts \
 exist but have no suitable transactions."))
 
 (define num-buckets 6)
 
 (define (setup-query query accounts date)
   (qof-query-set-book query (gnc-get-current-book))
-  (gnc:query-set-match-non-voids-only! query (gnc-get-current-book))
+  (xaccQueryAddClearedMatch
+   query (logand CLEARED-ALL (lognot CLEARED-VOIDED)) QOF-QUERY-AND)
   (xaccQueryAddAccountMatch query accounts QOF-GUID-MATCH-ANY QOF-QUERY-AND)
   (xaccQueryAddDateMatchTT query #f 0 #t date QOF-QUERY-AND)
   (qof-query-set-sort-order query (list SPLIT-TRANS TRANS-DATE-POSTED) '() '())
@@ -160,7 +161,7 @@ exist but have no suitable transactions."))
                     (gncAddressGetPhone addr)
                     (gncAddressGetFax addr)
                     (gncAddressGetEmail addr)
-                    (if (gncOwnerGetActive owner) (_ "Y") (_ "N")))))
+                    (if (gncOwnerGetActive owner) (C_ "One-letter indication for 'yes'" "Y") (C_ "One-letter indication for 'no'" "N")))))
            (else address-list-names))))
     (fold-right (lambda (opt elt prev) (if opt (cons elt prev) prev))
                 '() address-list-options result-list)))
@@ -189,14 +190,14 @@ exist but have no suitable transactions."))
     (gnc:option-value (gnc:lookup-option options section name)))
 
   (define make-heading-list
-    (list (_ "Company")
-          (_ "Pre-Payment")
-          (_ "Current")
-          (_ "0-30 days")
-          (_ "31-60 days")
-          (_ "61-90 days")
-          (_ "91+ days")
-          (_ "Total")))
+    (list (G_ "Company")
+          (G_ "Pre-Payment")
+          (G_ "Current")
+          (G_ "0-30 days")
+          (G_ "31-60 days")
+          (G_ "61-90 days")
+          (G_ "91+ days")
+          (G_ "Total")))
 
   (let* ((type (if receivable ACCT-TYPE-RECEIVABLE ACCT-TYPE-PAYABLE))
          (accounts (filter (lambda (acc) (eqv? (xaccAccountGetType acc) type))
@@ -230,7 +231,9 @@ exist but have no suitable transactions."))
               (else (op-num (car aging1) (car aging2)))))))))
 
     ;; set default title
-    (gnc:html-document-set-title! document report-title)
+    (gnc:html-document-set-title!
+     document
+     (format #f "~a - ~a" report-title (qof-print-date report-date)))
 
     (cond
      ((null? accounts)
@@ -309,7 +312,7 @@ exist but have no suitable transactions."))
                               "number-cell"
                               (gnc:make-html-text
                                (gnc:html-markup-anchor
-                                (gnc:owner-report-text owner account)
+                                (gnc:owner-report-text owner account report-date)
                                 (gnc:make-gnc-monetary comm aging-total)))))
                             (options->address options receivable owner)))))
                       (sort owners-and-aging sort-aging<?))
@@ -319,7 +322,7 @@ exist but have no suitable transactions."))
                       (append
                        (if accounts>1? '(#f) '())
                        (list (gnc:make-html-table-cell/markup
-                              "total-label-cell" (_ "Total")))
+                              "total-label-cell" (G_ "Total")))
                        (map
                         (lambda (amt)
                           (gnc:make-html-table-cell/markup
@@ -337,7 +340,7 @@ exist but have no suitable transactions."))
                   (gnc:html-document-add-object!
                    document
                    (gnc:make-html-text
-                    (_ "Please note some transactions were not processed")
+                    (G_ "Please note some transactions were not processed")
                     (gnc:html-markup-ol
                      (map
                       (lambda (invalid-split)
@@ -370,7 +373,7 @@ exist but have no suitable transactions."))
                    (let ((type (xaccTransGetTxnType (xaccSplitGetParent this))))
                      (lp rest
                          acc-totals
-                         (cons (list (format #f (_ "Invalid Txn Type ~a") type) this)
+                         (cons (list (format #f (G_ "Invalid Txn Type ~a") type) this)
                                invalid-splits)
                          owners-and-aging)))
 
@@ -380,7 +383,7 @@ exist but have no suitable transactions."))
                    (gnc:warn "split " this " has no owner")
                    (lp rest
                        acc-totals
-                       (cons (list (_ "Payment has no owner") this) invalid-splits)
+                       (cons (list (G_ "Payment has no owner") this) invalid-splits)
                        owners-and-aging))
 
                   ((this . _)
