@@ -61,6 +61,7 @@
   (vector-ref columns-used 14))
 
 (define columns-used-size 15)
+(define reportname (N_ "Register"))
 
 (define (num-columns-required columns-used)
   (do ((i 0 (+ i 1))
@@ -126,27 +127,27 @@
   (let ((heading-list '()))
     (gnc:debug "Column-vector" column-vector)
     (if (date-col column-vector)
-        (addto! heading-list (_ "Date")))
+        (addto! heading-list (G_ "Date")))
     (if (num-col column-vector)
         (addto! heading-list (if action-for-num?
                                  (if ledger-type?
-                                     (_ "T-Num")
-                                     (_ "Num/Action"))
-                                 (_ "Num"))))
+                                     (G_ "T-Num")
+                                     (G_ "Num/Action"))
+                                 (G_ "Num"))))
     (if (description-col column-vector)
-        (addto! heading-list (_ "Description")))
+        (addto! heading-list (G_ "Description")))
     (if (memo-col column-vector)
-        (addto! heading-list (_ "Memo")))
+        (addto! heading-list (G_ "Memo")))
     (if (account-col column-vector)
         (addto! heading-list (if multi-rows?
-                                 (_ "Account")
-                                 (_ "Transfer"))))
+                                 (G_ "Account")
+                                 (G_ "Transfer"))))
     (if (shares-col column-vector)
-        (addto! heading-list (_ "Shares")))
+        (addto! heading-list (G_ "Shares")))
     (if (lot-col column-vector)
-        (addto! heading-list (_ "Lot")))
+        (addto! heading-list (G_ "Lot")))
     (if (price-col column-vector)
-        (addto! heading-list (_ "Price")))
+        (addto! heading-list (G_ "Price")))
     (if (amount-single-col column-vector)
         (addto! heading-list amount-string))
     (if (debit-col column-vector)
@@ -154,13 +155,13 @@
     (if (credit-col column-vector)
         (addto! heading-list credit-string))
     (if (value-single-col column-vector)
-        (addto! heading-list (_ "Value")))
+        (addto! heading-list (G_ "Value")))
     (if (value-debit-col column-vector)
-        (addto! heading-list (_ "Debit Value")))
+        (addto! heading-list (G_ "Debit Value")))
     (if (value-credit-col column-vector)
-        (addto! heading-list (_ "Credit Value")))
+        (addto! heading-list (G_ "Credit Value")))
     (if (balance-col column-vector)
-        (addto! heading-list (_ "Balance")))
+        (addto! heading-list (G_ "Balance")))
     (reverse heading-list)))
 
 (define (add-split-row table split column-vector row-style transaction-info?
@@ -224,8 +225,8 @@
                           ((2) (gnc-account-get-full-name
                                 (xaccSplitGetAccount
                                  (xaccSplitGetOtherSplit split))))
-                          ((1) (_ "None"))
-                          (else (_ "-- Split Transaction --"))))))))
+                          ((1) (G_ "None"))
+                          (else (G_ "-- Split Transaction --"))))))))
     (if (shares-col column-vector)
         (addto! row-contents
                 (gnc:make-html-table-cell/markup
@@ -366,9 +367,9 @@
   (gnc:register-reg-option
    (gnc:make-internal-option "__reg" "double" #f))
   (gnc:register-reg-option
-   (gnc:make-internal-option "__reg" "debit-string" (_ "Debit")))
+   (gnc:make-internal-option "__reg" "debit-string" (G_ "Debit")))
   (gnc:register-reg-option
-   (gnc:make-internal-option "__reg" "credit-string" (_ "Credit")))
+   (gnc:make-internal-option "__reg" "credit-string" (G_ "Credit")))
 
   (gnc:register-reg-option
    (gnc:make-string-option
@@ -558,6 +559,7 @@
          (total-value (gnc:make-commodity-collector))
          (debit-value (gnc:make-commodity-collector))
          (credit-value (gnc:make-commodity-collector))
+         (work-to-do (length splits))
          (action-for-num? (qof-book-use-split-action-for-num-field
                            (gnc-get-current-book))))
 
@@ -568,6 +570,7 @@
                         multi-rows? action-for-num? ledger-type?))
 
     (let loop ((splits splits)
+               (work-done 0)
                (odd-row? #t))
 
       (cond
@@ -577,19 +580,21 @@
        ;; add debit/credit totals to the table
        ;; ----------------------------------
        ((null? splits)
+        (gnc:report-percent-done 100)
+
         (when reg-report-show-totals?
-          (add-subtotal-row (_ "Total Debits") leader table used-columns
+          (add-subtotal-row (G_ "Total Debits") leader table used-columns
                             debit-collector "grand-total" #f)
-          (add-subtotal-row (_ "Total Credits") leader table used-columns
+          (add-subtotal-row (G_ "Total Credits") leader table used-columns
                             credit-collector "grand-total" #f)
-          (add-subtotal-row (_ "Total Value Debits") leader table used-columns
+          (add-subtotal-row (G_ "Total Value Debits") leader table used-columns
                             debit-value "grand-total" #t)
-          (add-subtotal-row (_ "Total Value Credits") leader table used-columns
+          (add-subtotal-row (G_ "Total Value Credits") leader table used-columns
                             credit-value "grand-total" #t))
         (when ledger-type?
-          (add-subtotal-row (_ "Net Change") leader table used-columns
+          (add-subtotal-row (G_ "Net Change") leader table used-columns
                             total-collector "grand-total" #f))
-        (add-subtotal-row (_ "Value Change") leader table used-columns
+        (add-subtotal-row (G_ "Value Change") leader table used-columns
                           total-value "grand-total" #t))
 
        ;; The general journal has a split that doesn't have an account
@@ -597,12 +602,15 @@
        ;; This split should be skipped or the report errors out.  See
        ;; bug #639082
        ((null? (xaccSplitGetAccount (car splits)))
-        (loop (cdr splits) (not odd-row?)))
+        (loop (cdr splits) (1+ work-done) (not odd-row?)))
 
        ;; ----------------------------------
        ;; process the splits list
        ;; ----------------------------------
        (else
+        (when (zero? (modulo work-done 200))
+          (gnc:report-percent-done (* 100 (/ work-done work-to-do))))
+
         (let* ((current (car splits))
                (current-row-style (if (or multi-rows? odd-row?)
                                       "normal-row"
@@ -638,6 +646,7 @@
              (xaccTransGetSplitList (xaccSplitGetParent current))))
 
           (loop (cdr splits)
+                (1+ work-done)
                 (not odd-row?))))))
     table))
 
@@ -654,6 +663,8 @@
          (title (opt-val "General" "Title"))
          (query (gnc-scm2query query-scm)))
 
+    (gnc:report-starting (G_ reportname))
+
     (qof-query-set-book query (gnc-get-current-book))
 
     (let* ((splits (if journal?
@@ -662,11 +673,13 @@
            (table (make-split-table splits
                                     (gnc:report-options report-obj)
                                     debit-string credit-string
-                                    (_ "Amount"))))
+                                    (G_ "Amount"))))
       (gnc:html-document-set-title! document title)
       (gnc:html-document-add-object! document table)
       (qof-query-destroy query))
 
+    (gnc:report-finished)
+
     document))
 
 (define register-report-guid "22104e02654c4adba844ee75a3f8d173")
@@ -680,7 +693,7 @@
 
 (gnc:define-report
  'version 1
- 'name (N_ "Register")
+ 'name reportname
  'report-guid register-report-guid
  'options-generator options-generator
  'renderer reg-renderer
