@@ -27,7 +27,7 @@
 GnuCash. One of the newer ~a options '~a' is not available, fallback to \
 the option '~a'."))
          (console-msg (format #f template type newoption fallback))
-         (ui-msg (format #f (_ template) type newoption fallback)))
+         (ui-msg (format #f (G_ template) type newoption fallback)))
     (gnc:gui-warn console-msg ui-msg)))
 
 (define (gnc:make-option
@@ -1680,8 +1680,11 @@ the option '~a'."))
       ("Void Transactions?" "Filter" "Void Transactions")
       ("Void Transactions" "Filter" "Void Transactions")
       ("Account Substring" "Filter" "Account Name Filter")
+      ("Enable links" #f "Enable Links")
       ;; invoice.scm, renamed November 2018
       ("Individual Taxes" #f "Use Detailed Tax Summary")
+      ;; income-gst-statement.scm
+      ("default format" #f "Default Format")
       ))
 
   (define (lookup-option section name)
